/****************************************************************************/
/* WARNING:                                                                 */
/* ======================================================================== */
/* When using the new functinality of the status checking please try to not */
/* use the RSMU_Read and RSMU_Write functions. If it is neccessary call     */
/* RSCMU_setCheckStatus function to restore your desired checking status.   */
/* After each call of the RSCMU_Read function the status checking is always */
/* off. This note does not regards to RSCMU_Query and RSCMU_QueryArray      */
/* functions.                                                               */
/****************************************************************************/
#ifndef __RSCMU_HEADER
#define __RSCMU_HEADER

/*=  Include File     =======================================================*/
#include <vpptype.h>

#if defined(_MSC_VER) || defined(_CVI_)
#define _OUTSIDEVEE_
#endif

#if (!defined _DLL) && (!defined _VXIPNP)
#define _REMOVE_VXIPNP_FUNCTIONS_
#endif

#if defined(__cplusplus) || defined(__cplusplus__)
extern "C" {
#endif

/*****************************************************************************/
/*= Define Instrument Specific Error/Warning Codes Here =====================*/
/*****************************************************************************/
/*---------------------------------------------------------------------------*/
/* The codes for instrument specific ERRORS must be in the range             */
/* 0xBFFC0900 to 0xBFFC0FFF and defined as follows:                          */
/* #define PREFIX_SPECIFIC_ERROR (VI_INSTR_ERROR_OFFSET + n)                 */
/*                                                                           */
/* The codes for instrument specific WARNINGS must be in the range           */
/* 0x3FFC0900 to 0x3FFC0FFF and defined as follows:                          */
/* #define PREFIX_SPECIFIC_WARNING (VI_INSTR_WARNINGS_OFFSET + n)            */
/*                                                                           */
/* Where n represents each instrument specific error/warning number.         */
/* The valid range for n is 0x000 to 0x0FF  for CMU Base                     */
/* The valid range for n is 0x100 to 0x17F  for K2G Option (GSM MS)          */
/* The valid range for n is 0x180 to 0x1FF  for K3G Option (GSM BS)          */
/* The valid range for n is 0x200 to 0x27F  for IS136 Option (MS)            */
/* The valid range for n is 0x280 to 0x2FF  for IS136 Option (BS)            */
/* For ease of use the lower 16 bits of warnings and errors should not       */
/* overlap in the same driver.                                               */
/*                                                                           */
/*---------------------------------------------------------------------------*/

#ifdef _OUTSIDEVEE_

#define VI_INSTR_WARNING_OFFSET                          (0x3FFC0900L)
#define VI_INSTR_ERROR_OFFSET                  (_VI_ERROR+0x3FFC0900L)

#define RSCMU_LIST_OF_SPECIFIC_ERROR_MESSAGES \
EXPAND(RSCMU_ERROR_FAIL_ID_QUERY,            (VI_ERROR_FAIL_ID_QUERY),         "Identification query failed") \
EXPAND(RSCMU_ERROR_STATUS_BYTE,              (VI_INSTR_ERROR_OFFSET + 0x000L), "Status Byte register error occurred") \
EXPAND(RSCMU_ERROR_INVALID_STATUS_DEV,       (VI_INSTR_ERROR_OFFSET + 0x001L), "The RSCMU is in an internal state where the query is not allowed") \
EXPAND(RSCMU_ERROR_TIMEOUT,                  (VI_INSTR_ERROR_OFFSET + 0x002L), "Timeout expired before operation is completed") \
EXPAND(RSCMU_ERROR_NAN,                      (VI_INSTR_ERROR_OFFSET + 0x003L), "The value returned is not a number (NAN) because the CMU 200\nis in a state where the query is not allowed.") \
EXPAND(RSCMU_ERROR_INF,                      (VI_INSTR_ERROR_OFFSET + 0x004L), "The value returned is overflowed (positive INFinity: +9.9E37)") \
EXPAND(RSCMU_ERROR_NINF,                     (VI_INSTR_ERROR_OFFSET + 0x005L), "The value returned is overflowed (Negative INFinity: -9.9E37)") \
EXPAND(RSCMU_ERROR_INTERPRETING_RESPONSE,    (VI_INSTR_ERROR_OFFSET + 0x006L), "Unable to interpret the instrument response") \
EXPAND(RSCMU_ERROR_MEMORY_ALLOCATION,        (VI_INSTR_ERROR_OFFSET + 0x007L), "Unable to allocate memory block of the requested size") \
EXPAND(RSCMU_ERROR_INVALID_FCT_GRP,          (VI_INSTR_ERROR_OFFSET + 0x008L), "The function group is not assigned to a secondary address") \
EXPAND(RSCMU_ERROR_INVALID_MEAS_STATUS,      (VI_INSTR_ERROR_OFFSET + 0x009L), "The RSCMU is in an internal measurement status where the command is not allowed") \
EXPAND(RSCMU_ERROR_GEN_STAT_UNKNOWN,         (VI_INSTR_ERROR_OFFSET + 0x00AL), "The generator status is unknown") \
EXPAND(RSCMU_ERROR_MEAS_STAT_UNKNOWN,        (VI_INSTR_ERROR_OFFSET + 0x00BL), "The measurement status is unknown") \
EXPAND(RSCMU_ERROR_INVALID_LIMIT_CHECK,      (VI_INSTR_ERROR_OFFSET + 0x00CL), "Unable to interpret the instrument limit check response") \
EXPAND(RSCMU_ERROR_EOF,                      (VI_INSTR_ERROR_OFFSET + 0x00DL), "sscanf attempts to read at end-of-string") \
EXPAND(RSCMU_ERROR_FILE_EXISTS,              (VI_INSTR_ERROR_OFFSET + 0x00EL), "File exists, cannot overwrite") \
EXPAND(RSCMU_ERROR_OPEN_FILE,                (VI_INSTR_ERROR_OFFSET + 0x00FL), "Opening the specified file") \
EXPAND(RSCMU_ERROR_WRITE_FILE,               (VI_INSTR_ERROR_OFFSET + 0x010L), "A file write error is encountered") \
EXPAND(RSCMU_ERROR_PARAMETER1,               (VI_INSTR_ERROR_OFFSET + 0x011L), "Parameter 1 out of range") \
EXPAND(RSCMU_ERROR_PARAMETER2,               (VI_INSTR_ERROR_OFFSET + 0x012L), "Parameter 2 out of range") \
EXPAND(RSCMU_ERROR_PARAMETER3,               (VI_INSTR_ERROR_OFFSET + 0x013L), "Parameter 3 out of range") \
EXPAND(RSCMU_ERROR_PARAMETER4,               (VI_INSTR_ERROR_OFFSET + 0x014L), "Parameter 4 out of range") \
EXPAND(RSCMU_ERROR_PARAMETER5,               (VI_INSTR_ERROR_OFFSET + 0x015L), "Parameter 5 out of range") \
EXPAND(RSCMU_ERROR_PARAMETER6,               (VI_INSTR_ERROR_OFFSET + 0x016L), "Parameter 6 out of range") \
EXPAND(RSCMU_ERROR_PARAMETER7,               (VI_INSTR_ERROR_OFFSET + 0x017L), "Parameter 7 out of range") \
EXPAND(RSCMU_ERROR_PARAMETER8,               (VI_INSTR_ERROR_OFFSET + 0x018L), "Parameter 8 out of range") \
EXPAND(RSCMU_ERROR_PARAMETER9,               (VI_INSTR_ERROR_OFFSET + 0x019L), "Parameter 9 out of range") \
EXPAND(RSCMU_ERROR_PARAMETER10,              (VI_INSTR_ERROR_OFFSET + 0x01AL), "Parameter 10 out of range") \
EXPAND(RSCMU_ERROR_PARAMETER11,              (VI_INSTR_ERROR_OFFSET + 0x01BL), "Parameter 11 out of range") \
EXPAND(RSCMU_ERROR_PARAMETER12,              (VI_INSTR_ERROR_OFFSET + 0x01CL), "Parameter 12 out of range") \
EXPAND(RSCMU_ERROR_PARAMETER13,              (VI_INSTR_ERROR_OFFSET + 0x01DL), "Parameter 13 out of range") \
EXPAND(RSCMU_ERROR_PARAMETER14,              (VI_INSTR_ERROR_OFFSET + 0x01EL), "Parameter 14 out of range") \
EXPAND(RSCMU_ERROR_PARAMETER15,              (VI_INSTR_ERROR_OFFSET + 0x01FL), "Parameter 15 out of range") \
EXPAND(RSCMU_ERROR_PARAMETER16,              (VI_INSTR_ERROR_OFFSET + 0x020L), "Parameter 16 out of range") \
EXPAND(RSCMU_ERROR_PARAMETER17,              (VI_INSTR_ERROR_OFFSET + 0x021L), "Parameter 17 out of range") \
EXPAND(RSCMU_ERROR_PARAMETER18,              (VI_INSTR_ERROR_OFFSET + 0x022L), "Parameter 18 out of range") \
EXPAND(RSCMU_ERROR_PARAMETER19,              (VI_INSTR_ERROR_OFFSET + 0x023L), "Parameter 19 out of range") \
EXPAND(RSCMU_ERROR_PARAMETER20,              (VI_INSTR_ERROR_OFFSET + 0x024L), "Parameter 20 out of range") \
EXPAND(RSCMU_ERROR_PARAMETER21,              (VI_INSTR_ERROR_OFFSET + 0x025L), "Parameter 21 out of range") \
EXPAND(RSCMU_ERROR_PARAMETER22,              (VI_INSTR_ERROR_OFFSET + 0x026L), "Parameter 22 out of range") \
EXPAND(RSCMU_DO_FAIL_IF_NO_QUERY,            (VI_INSTR_ERROR_OFFSET + 0x027L), "Do Identification to determine type of CMU") \
EXPAND(RSCMU_ERROR_NO_DC_ALLOWED,            (VI_INSTR_ERROR_OFFSET + 0x028L), "No DC allowed for AC bandpass") \
EXPAND(RSCMU_ERROR_FW_VERSION,               (VI_INSTR_ERROR_OFFSET + 0x029L), "Incompatible CMU Firmware - CMU FW V2.10 or higher required") \
EXPAND(RSCMU_ERROR_FW_VERSION_2_15,          (VI_INSTR_ERROR_OFFSET + 0x02AL), "Incompatible CMU Firmware - CMU FW V2.15 or higher required") \
EXPAND(RSCMU_ERROR_FW_VERSION_2_16,          (VI_INSTR_ERROR_OFFSET + 0x02BL), "Incompatible CMU Firmware - CMU FW V2.16 or higher required") \
EXPAND(RSCMU_ERROR_FW_VERSION_2_50,          (VI_INSTR_ERROR_OFFSET + 0x02CL), "Incompatible CMU Firmware - CMU FW V2.50 or higher required") \
EXPAND(RSCMU_ERROR_FW_VERSION_2_53,          (VI_INSTR_ERROR_OFFSET + 0x02DL), "Incompatible CMU Firmware - CMU FW V2.53 or higher required") \
EXPAND(RSCMU_ERROR_FW_VERSION_2_62,          (VI_INSTR_ERROR_OFFSET + 0x02EL), "Incompatible CMU Firmware - CMU FW V2.62 or higher required") \
EXPAND(RSCMU_ERROR_FW_VERSION_3_00,          (VI_INSTR_ERROR_OFFSET + 0x02FL), "Incompatible CMU Firmware - CMU FW V3.00 or higher required") \
EXPAND(RSCMU_ERROR_FW_VERSION_3_01,          (VI_INSTR_ERROR_OFFSET + 0x030L), "Incompatible CMU Firmware - CMU FW V3.01 or higher required") \
EXPAND(RSCMU_ERROR_FW_VERSION_3_05,          (VI_INSTR_ERROR_OFFSET + 0x031L), "Incompatible CMU Firmware - CMU FW V3.05 or higher required") \
EXPAND(RSCMU_ERROR_FW_VERSION_3_07,          (VI_INSTR_ERROR_OFFSET + 0x032L), "Incompatible CMU Firmware - CMU FW V3.07 or higher required") \
EXPAND(RSCMU_ERROR_FW_VERSION_3_08,          (VI_INSTR_ERROR_OFFSET + 0x033L), "Incompatible CMU Firmware - CMU FW V3.08 or higher required") \
EXPAND(RSCMU_ERROR_FW_VERSION_3_10,          (VI_INSTR_ERROR_OFFSET + 0x034L), "Incompatible CMU Firmware - CMU FW V3.10 or higher required") \
EXPAND(RSCMU_ERROR_FW_VERSION_3_09,          (VI_INSTR_ERROR_OFFSET + 0x035L), "Incompatible CMU Firmware - CMU FW V3.09 or higher required") \
EXPAND(RSCMU_ERROR_FW_VERSION_2_66,          (VI_INSTR_ERROR_OFFSET + 0x036L), "Incompatible CMU Firmware - CMU FW V2.66 or higher required") \
EXPAND(RSCMU_ERROR_INSTRUMENT_ERROR,         (VI_INSTR_ERROR_OFFSET + 0x037L), "ESR Byte Error Occured") \
EXPAND(RSCMU_ERROR_PARAMETER23,              (VI_INSTR_ERROR_OFFSET + 0x038L), "Parameter 23 out of range") \
EXPAND(RSCMU_ERROR_PARAMETER24,              (VI_INSTR_ERROR_OFFSET + 0x039L), "Parameter 24 out of range") \
EXPAND(RSCMU_ERROR_PARAMETER25,              (VI_INSTR_ERROR_OFFSET + 0x03AL), "Parameter 25 out of range") \
EXPAND(RSCMU_ERROR_PARAMETER26,              (VI_INSTR_ERROR_OFFSET + 0x03BL), "Parameter 26 out of range") \
EXPAND(RSCMU_ERROR_PARAMETER27,              (VI_INSTR_ERROR_OFFSET + 0x03CL), "Parameter 27 out of range") \
EXPAND(RSCMU_ERROR_PARAMETER28,              (VI_INSTR_ERROR_OFFSET + 0x03DL), "Parameter 28 out of range") \
EXPAND(RSCMU_ERROR_PARAMETER29,              (VI_INSTR_ERROR_OFFSET + 0x03EL), "Parameter 29 out of range") \
EXPAND(RSCMU_ERROR_PARAMETER30,              (VI_INSTR_ERROR_OFFSET + 0x03FL), "Parameter 30 out of range") \
EXPAND(RSCMU_ERROR_PARAMETER31,              (VI_INSTR_ERROR_OFFSET + 0x040L), "Parameter 31 out of range") \
EXPAND(RSCMU_ERROR_PARAMETER32,              (VI_INSTR_ERROR_OFFSET + 0x041L), "Parameter 32 out of range") \
EXPAND(RSCMU_ERROR_PARAMETER33,              (VI_INSTR_ERROR_OFFSET + 0x042L), "Parameter 33 out of range") \
EXPAND(RSCMU_ERROR_PARAMETER34,              (VI_INSTR_ERROR_OFFSET + 0x043L), "Parameter 34 out of range") \
EXPAND(RSCMU_ERROR_FW_VERSION_3_11,          (VI_INSTR_ERROR_OFFSET + 0x044L), "Incompatible CMU Firmware - CMU FW V3.11 or higher required") \
EXPAND(RSCMU_ERROR_FW_VERSION_3_20,          (VI_INSTR_ERROR_OFFSET + 0x045L), "Incompatible CMU Firmware - CMU FW V3.20 or higher required") \
EXPAND(RSCMU_ERROR_FW_VERSION_3_21,          (VI_INSTR_ERROR_OFFSET + 0x046L), "Incompatible CMU Firmware - CMU FW V3.21 or higher required") \
EXPAND(RSCMU_ERROR_FW_VERSION_3_22,          (VI_INSTR_ERROR_OFFSET + 0x047L), "Incompatible CMU Firmware - CMU FW V3.22 or higher required") \
EXPAND(RSCMU_ERROR_FW_VERSION_3_25,          (VI_INSTR_ERROR_OFFSET + 0x048L), "Incompatible CMU Firmware - CMU FW V3.25 or higher required") \
EXPAND(RSCMU_ERROR_FW_VERSION_3_40,          (VI_INSTR_ERROR_OFFSET + 0x049L), "Incompatible CMU Firmware - CMU FW V3.40 or higher required") \
EXPAND(RSCMU_ERROR_FW_VERSION_3_42,          (VI_INSTR_ERROR_OFFSET + 0x04AL), "Incompatible CMU Firmware - CMU FW V3.42 or higher required") \
EXPAND(RSCMU_ERROR_FW_VERSION_3_50,          (VI_INSTR_ERROR_OFFSET + 0x04BL), "Incompatible CMU Firmware - CMU FW V3.50 or higher required") \
EXPAND(RSCMU_ERROR_FW_VERSION_3_51,          (VI_INSTR_ERROR_OFFSET + 0x04CL), "Incompatible CMU Firmware - CMU FW V3.51 or higher required") \
EXPAND(RSCMU_ERROR_FW_VERSION_3_52,          (VI_INSTR_ERROR_OFFSET + 0x04DL), "Incompatible CMU Firmware - CMU FW V3.52 or higher required") \
EXPAND(RSCMU_ERROR_FW_VERSION_3_60,          (VI_INSTR_ERROR_OFFSET + 0x04EL), "Incompatible CMU Firmware - CMU FW V3.60 or higher required") \
EXPAND(RSCMU_ERROR_FW_VERSION_3_80,          (VI_INSTR_ERROR_OFFSET + 0x04FL), "Incompatible CMU Firmware - CMU FW V3.80 or higher required") \
EXPAND(RSCMU_ERROR_FW_VERSION_3_81,          (VI_INSTR_ERROR_OFFSET + 0x050L), "Incompatible CMU Firmware - CMU FW V3.81 or higher required") \
EXPAND(RSCMU_ERROR_STATUS_MODE,              (VI_INSTR_ERROR_OFFSET + 0x051L), "Undefined Error Query Mode !") \
EXPAND(RSCMU_ERROR_FW_VERSION_3_85,          (VI_INSTR_ERROR_OFFSET + 0x052L), "Incompatible CMU Firmware - CMU FW V3.85 or higher required") \
EXPAND(RSCMU_ERROR_FW_VERSION_4_00,          (VI_INSTR_ERROR_OFFSET + 0x053L), "Incompatible CMU Firmware - CMU FW V4.10 or higher required") \
EXPAND(RSCMU_ERROR_FW_VERSION_4_10,          (VI_INSTR_ERROR_OFFSET + 0x054L), "Incompatible CMU Firmware - CMU FW V4.10 or higher required") \
EXPAND(RSCMU_ERROR_FW_VERSION_4_20,          (VI_INSTR_ERROR_OFFSET + 0x055L), "Incompatible CMU Firmware - CMU FW V4.20 or higher required") \
EXPAND(RSCMU_ERROR_FW_VERSION_4_23,          (VI_INSTR_ERROR_OFFSET + 0x056L), "Incompatible CMU Firmware - CMU FW V4.23 or higher required") \
EXPAND(RSCMU_ERROR_FW_VERSION_4_30,          (VI_INSTR_ERROR_OFFSET + 0x057L), "Incompatible CMU Firmware - CMU FW V4.30 or higher required") \
EXPAND(RSCMU_ERROR_FW_VERSION_4_32,          (VI_INSTR_ERROR_OFFSET + 0x058L), "Incompatible CMU Firmware - CMU FW V4.32 or higher required") \
EXPAND(RSCMU_ERROR_FW_VERSION_4_35,          (VI_INSTR_ERROR_OFFSET + 0x059L), "Incompatible CMU Firmware - CMU FW V4.35 or higher required") \
EXPAND(RSCMU_ERROR_FW_VERSION_4_37,          (VI_INSTR_ERROR_OFFSET + 0x05AL), "Incompatible CMU Firmware - CMU FW V4.37 or higher required") \
EXPAND(RSCMU_ERROR_FW_VERSION_4_50,          (VI_INSTR_ERROR_OFFSET + 0x05BL), "Incompatible CMU Firmware - CMU FW V4.50 or higher required") \
EXPAND(RSCMU_ERROR_FW_VERSION_4_55,          (VI_INSTR_ERROR_OFFSET + 0x05CL), "Incompatible CMU Firmware - CMU FW V4.55 or higher required") \
EXPAND(RSCMU_ERROR_FW_VERSION_5_00,          (VI_INSTR_ERROR_OFFSET + 0x05DL), "Incompatible CMU Firmware - CMU FW V5.00 or higher required")
typedef enum {
#define EXPAND(id, value, text) id = value,
  RSCMU_LIST_OF_SPECIFIC_ERROR_MESSAGES
#undef EXPAND
} RSCMU_ErrorList;

/*****************************************************************************/
/*                                 DEFINES                                   */
/*****************************************************************************/

/*---------------------------------------------------------------------------*/
/* Available CMU200 Versions
/*---------------------------------------------------------------------------*/

#define RSCMU_LIST_OF_AVAILABLE_CMU200_FW_VERSIONS \
EXPAND2 (RSCMU200_V2_10, 210, "V2.10") \
EXPAND2 (RSCMU200_V2_11, 211, "V2.11") \
EXPAND2 (RSCMU200_V2_12, 212, "V2.12") \
EXPAND2 (RSCMU200_V2_15, 215, "V2.15") \
EXPAND2 (RSCMU200_V2_16, 216, "V2.16") \
EXPAND2 (RSCMU200_V2_17, 217, "V2.17") \
EXPAND2 (RSCMU200_V2_50, 250, "V2.50") \
EXPAND2 (RSCMU200_V2_53, 253, "V2.53") \
EXPAND2 (RSCMU200_V2_62, 262, "V2.62") \
EXPAND2 (RSCMU200_V2_66, 266, "V2.66") \
EXPAND2 (RSCMU200_V3_00, 300, "V3.00") \
EXPAND2 (RSCMU200_V3_01, 301, "V3.01") \
EXPAND2 (RSCMU200_V3_05, 305, "V3.05") \
EXPAND2 (RSCMU200_V3_07, 307, "V3.07") \
EXPAND2 (RSCMU200_V3_08, 308, "V3.08") \
EXPAND2 (RSCMU200_V3_09, 309, "V3.09") \
EXPAND2 (RSCMU200_V3_10, 310, "V3.10") \
EXPAND2 (RSCMU200_V3_11, 311, "V3.11") \
EXPAND2 (RSCMU200_V3_20, 320, "V3.20") \
EXPAND2 (RSCMU200_V3_21, 321, "V3.21") \
EXPAND2 (RSCMU200_V3_22, 322, "V3.22") \
EXPAND2 (RSCMU200_V3_25, 325, "V3.25") \
EXPAND2 (RSCMU200_V3_40, 340, "V3.40") \
EXPAND2 (RSCMU200_V3_42, 342, "V3.42") \
EXPAND2 (RSCMU200_V3_50, 350, "V3.50") \
EXPAND2 (RSCMU200_V3_51, 351, "V3.51") \
EXPAND2 (RSCMU200_V3_52, 352, "V3.52") \
EXPAND2 (RSCMU200_V3_53, 353, "V3.53") \
EXPAND2 (RSCMU200_V3_54, 354, "V3.54") \
EXPAND2 (RSCMU200_V3_60, 360, "V3.60") \
EXPAND2 (RSCMU200_V3_62, 362, "V3.62") \
EXPAND2 (RSCMU200_V3_65, 365, "V3.65") \
EXPAND2 (RSCMU200_V3_80, 380, "V3.80") \
EXPAND2 (RSCMU200_V3_81, 381, "V3.81") \
EXPAND2 (RSCMU200_V3_82, 382, "V3.82") \
EXPAND2 (RSCMU200_V3_85, 385, "V3.85") \
EXPAND2 (RSCMU200_V4_00, 400, "V4.00") \
EXPAND2 (RSCMU200_V4_10, 410, "V4.10") \
EXPAND2 (RSCMU200_V4_20, 420, "V4.20") \
EXPAND2 (RSCMU200_V4_23, 423, "V4.23") \
EXPAND2 (RSCMU200_V4_30, 430, "V4.30") \
EXPAND2 (RSCMU200_V4_32, 432, "V4.32") \
EXPAND2 (RSCMU200_V4_35, 435, "V4.35") \
EXPAND2 (RSCMU200_V4_37, 437, "V4.37") \
EXPAND2 (RSCMU200_V4_50, 450, "V4.50") \
EXPAND2 (RSCMU200_V4_55, 455, "V4.55") \
EXPAND2 (RSCMU200_V5_00, 500, "V5.00") 

typedef enum {
#define EXPAND2(id, value, text) id = value,
    RSCMU_LIST_OF_AVAILABLE_CMU200_FW_VERSIONS
#undef EXPAND2
} RSCMU200_FWVersionList;

#endif // _OUTSIDEVEE_

/*---------------------------------------------------------------------------*/
/* File I/O buffer size:
/*---------------------------------------------------------------------------*/
#define WR_BUFFER_SIZE             512L
#define RD_BUFFER_SIZE             512L
#define MID_BUFFER_SIZE           2048L
#define RD_BUFFER_SIZE_ARRAY     32767L
// Buffer size = 32768 results * (16 digits + 1 space)
#define RD_IQREC_SIZE_ARRAY     557056L

#define RSCMU_200          1
#define RSCMU_300          2
#define RSCBT              3

#define RSCMU_SECONDARY_ADDRESS_INVALID  -1
#define RSCMU_SECONDARY_ADDRESS_MIN  1
#define RSCMU_SECONDARY_ADDRESS_MAX 30

#define RSCMU_TMO_VALUE           10000

//#ifdef _OUTSIDEVEE_

// Logical values:
#define RSCMU_FALSE (0!=0)
#define RSCMU_TRUE  (0==0)

// On/Off values:
#define RSCMU_ON      VI_ON
#define RSCMU_OFF     VI_OFF
#define RSCMU_VAL_ON  VI_ON
#define RSCMU_VAL_OFF VI_OFF

// None value:
#define RSCMU_NONE    VI_OFF

//#endif

#ifndef _OUTSIDEVEE_

// Logical values:
#define RSCMU_FALSE 0
#define RSCMU_TRUE  1

// None value:
#define RSCMU_NONE    0

#endif

// Mathematical Values
#define RSCMU_NAN                 9.91e+37
#define RSCMU_NAN_VI_INT32        0x80000000

//Function Group Names FW2.0
#define RSCMU_NOT_MAPPED          -1
#define RSCMU_BASE                 0
#define RSCMU_RF_NSIG              1
#define RSCMU_GSM400MS_NSIG        2
#define RSCMU_GSM400MS_SIG         3
#define RSCMU_GSM850MS_NSIG        4
#define RSCMU_GSM850MS_SIG         5
#define RSCMU_GSM900MS_NSIG        6
#define RSCMU_GSM900MS_SIG         7
#define RSCMU_GSMGT800MS_SIG       8   /*upd V5.00*/ 
#define RSCMU_GSM1800MS_NSIG      10
#define RSCMU_GSM1800MS_SIG       11
#define RSCMU_GSM1900MS_NSIG      14
#define RSCMU_GSM1900MS_SIG       15
#define RSCMU_IS136800MS_NSIG     18
#define RSCMU_IS136800MS_SIG      19
#define RSCMU_IS1361900MS_NSIG    20
#define RSCMU_IS1361900MS_SIG     21
#define RSCMU_AUDIO_NSIG          22
#define RSCMU_AMPSMS_NSIG         23
#define RSCMU_AMPSMS_SIG          24
#define RSCMU_CDMA800MS_NSIG      25
#define RSCMU_CDMA800MS_SIG       26
#define RSCMU_CDMA1900MS_NSIG     27
#define RSCMU_CDMA1900MS_SIG      28
#define RSCMU_BLUETOOTH_NSIG      29
#define RSCMU_BLUETOOTH_SIG       30
#define RSCMU_WCDMA1900FDDMS_NSIG 31
#define RSCMU_WCDMA1900FDDMS_SIG  32
#define RSCMU_CDMA2K450MS_NSIG    33
#define RSCMU_CDMA2K450MS_SIG     34
#define RSCMU_CDMA2KCELLMS_NSIG   35
#define RSCMU_CDMA2KCELLMS_SIG    36
#define RSCMU_CDMA2KPCSMS_NSIG    37
#define RSCMU_CDMA2KPCSMS_SIG     38
#define RSCMU_CDMA2KIMT2KMS_NSIG  39
#define RSCMU_CDMA2KIMT2KMS_SIG   40
#define RSCMU_WCDMA_NB_NSIG       41
#define RSCMU_EVDO1xAT_NSIG       42
#define RSCMU_WCDMA_NB_SIG        43
#define RSCMU_EVDO1xAT_SIG        44

//CMU 300 Function Group Names FW2.0
#define RSCMU300_NOT_MAPPED         -1
#define RSCMU300_BASE                0
#define RSCMU300_RF_NSIG             1
#define RSCMU300_GSM400BS_NSIG       4
#define RSCMU300_GSM400BS_SIG        5
#define RSCMU300_GSM850BS_NSIG       6
#define RSCMU300_GSM850BS_SIG        7
#define RSCMU300_GSM900BS_NSIG       8
#define RSCMU300_GSM900BS_SIG        9
#define RSCMU300_GSM1800BS_NSIG      12
#define RSCMU300_GSM1800BS_SIG       13
#define RSCMU300_GSM1900BS_NSIG      16
#define RSCMU300_GSM1900BS_SIG       17
#define RSCMU300_AUDIO_NSIG          22
#define RSCMU300_AMPSMS_NSIG         23
#define RSCMU300_AMPSMS_SIG          24
#define RSCMU300_CDMA800MS_NSIG      25
#define RSCMU300_CDMA800MS_SIG       26
#define RSCMU300_CDMA1900MS_NSIG     27
#define RSCMU300_CDMA1900MS_SIG      28
#define RSCMU300_BLUETOOTH_NSIG      29
#define RSCMU300_BLUETOOTH_SIG       30

//Units
#define RSCMU_HZ                  0
#define RSCMU_KHZ                 1
#define RSCMU_MHZ                 2
#define RSCMU_GHZ                 3
#define RSCMU_US                  0
#define RSCMU_MS                  1
#define RSCMU_S                   2
#define RSCMU_CHANNEL             4

#define RSCMU_10HZ                0
#define RSCMU_20HZ                1
#define RSCMU_30HZ                2
#define RSCMU_50HZ                3
#define RSCMU_100HZ               4
#define RSCMU_200HZ               5
#define RSCMU_300HZ               6
#define RSCMU_500HZ               7
#define RSCMU_1KHZ                8
#define RSCMU_2KHZ                9
#define RSCMU_3KHZ               10
#define RSCMU_5KHZ               11
#define RSCMU_10KHZ              12
#define RSCMU_20KHZ              13
#define RSCMU_30KHZ              14
#define RSCMU_50KHZ              15
#define RSCMU_100KHZ             16
#define RSCMU_200KHZ             17
#define RSCMU_300KHZ             18
#define RSCMU_500KHZ             19
#define RSCMU_1MHZ               20
#define RSCMU_WIDE               21
#define RSCMU_FREQ_AUTO          21
#define RSCMU_TDMA               21
#define RSCMU_CDMA               22

//SCPI Connection
#define RSCMU_GPIB                0
#define RSCMU_COM                 1
#define RSCMU_COM1                1
#define RSCMU_COM2                2

//Parity
#define RSCMU_PARITY_NONE         0
#define RSCMU_PARITY_ODD          1
#define RSCMU_PARITY_EVEN         2

//Protocol
#define RSCMU_PROTOCOL_NONE       0
#define RSCMU_PROTOCOL_XON        1
#define RSCMU_PROTOCOL_ACK        2

// Status byte
#define RSCMU_STB_OFF             0
#define RSCMU_STB_ON              1

//Query
#define RSCMU_DO_QUERY            1
#define RSCMU_SKIP_QUERY          0

//Reset
#define RSCMU_RESET_ON            1
#define RSCMU_RESET_OFF           0

//Reference Frequency
#define RSCMU_INTERNAL            0
#define RSCMU_EXTERNAL            1
#define RSCMU_REF_FRQ_MIN         1.2190
#define RSCMU_REF_FRQ_MAX         39.0

//Attenuation
#define RSCMU_NORM                0
#define RSCMU_LNO                 1
#define RSCMU_LDIS                2
#define RSCMU_LOW_NOISE           1
#define RSCMU_LOW_DIST            2

//Trigger Condition
#define RSCMU_IMM                 0
#define RSCMU_FRUN                0
#define RSCMU_RFP                 1
#define RSCMU_IFP                 2
#define RSCMU_EXT                 3
#define RSCMU_SIGN                3
#define RSCBT_POW                 4

//Trigger Condition
#define RSCMU_LOW                 0
#define RSCMU_MED                 1
#define RSCMU_HIGH                2

//Trigger Source External
#define RSCMU_PIN6                 0
#define RSCMU_PIN7                 1
#define RSCMU_PIN8                 2

//I/Q-IF Enums
#define RSCMU_BYP                  0
#define RSCMU_BYIQ                 1
#define RSCMU_XOIO                 2
#define RSCMU_IOIO                 3
#define RSCMU_IOXO                 4
#define RSCMU_FPAT                 5
#define RSCMU_UDEF                 6

//Measurement Repetition
#define RSCMU_STOP_ON             1
#define RSCMU_STOP_ALIM           1
#define RSCMU_STOP_FLIM           2
#define RSCMU_STEP                1
#define RSCMU_STEP_ON             1
#define RSCMU_ON_LIMIT_FAILURE    1

// Measurement Repetition FW 2.0
#define RSCMU_CONTINUOUS          0
#define RSCMU_SINGLE_SHOT         1
#define RSCMU_MULTIPLE            2

// Result Mode
#define RSCMU_RESULTMODE_ARRAY    0
#define RSCMU_RESULTMODE_SCALAR   1

// Event Reporting
#define RSCMU_SRQ                 1
#define RSCMU_SOPC                2
#define RSCMU_SRSQ                3

// TimeOuts
#define RSCMU_SENS_TRIG_MEAS_TMO_MIN    1.0
#define RSCMU_SENS_TRIG_MEAS_TMO_MAX    1000.0

// Audio channels
#define RSCMU_ALL_AF              0
#define RSCMU_AF1                 1
#define RSCMU_AF2                 2

// Multitone results
#define RSCMU_RLEV                0
#define RSCMU_TON                 1

// Measurement time mode
#define RSCMU_LOWF                0
#define RSCMU_EXPF                1

// Multitone level mode
#define RSCMU_SEP                 0
#define RSCMU_TLEV                1

// Test Object defines
#define RSCMU_POW        0
#define RSCMU_MOD        1
#define RSCMU_SPEC       2
#define RSCMU_SPOW       3
#define RSCMU_WPOW       4
#define RSCMU_SPECMOD    5
#define RSCMU_SPECSWIT   6
#define RSCMU_POWMPR     7
#define RSCMU_POWSLOT    8
#define RSCMU_POWXSL     9
#define RSCMU_POWFRAM   10
#define RSCMU_POWPCL    11
#define RSCMU_MODXPER   12
#define RSCMU_MODOVER   13
#define RSCMU_MODEVM    14
#define RSCMU_MODPERR   15
#define RSCMU_MODMERR   16
#define RSCMU_POWABUR   17
#define RSCMU_POWMSL    18
#define RSCMU_NPOW      19
#define RSCMU_RFNPOW    20
#define RSCMU_SPECMSW   21

// Modulation
#define RSCMU_GMSK       1
#define RSCMU_EPSK       2

// Command defines
#define RSCMU_COMMAND_CONF      0
#define RSCMU_COMMAND_INIT      1
#define RSCMU_COMMAND_ABOR      2
#define RSCMU_COMMAND_STOP      3
#define RSCMU_COMMAND_CONT      4
#define RSCMU_COMMAND_READ      5
#define RSCMU_COMMAND_FETC      6
#define RSCMU_COMMAND_SAMP      7
#define RSCMU_COMMAND_CALC      8

/*===========================================================================*/
/*                          Measurement Control                              */
/*===========================================================================*/
// Generator Status
#define RSCMU_GEN_STAT_OFF        0
#define RSCMU_GEN_STAT_RUN        1
#define RSCMU_GEN_STAT_ERR        2

// Measurement Status
#define RSCMU_MEAS_STAT_OFF       0
#define RSCMU_MEAS_STAT_RUN       1
#define RSCMU_MEAS_STAT_STOP      2
#define RSCMU_MEAS_STAT_ERR       3
#define RSCMU_MEAS_STAT_STEP      4
#define RSCMU_MEAS_STAT_RDY       5

// Sensitivity Measurement Status
#define RSCMU_MEAS_STAT_PASS      0
#define RSCMU_MEAS_STAT_INV       1
#define RSCMU_MEAS_STAT_FAIL      2
#define RSCMU_MEAS_STAT_TMER      3
#define RSCMU_MEAS_STAT_IMP       4

/*===========================================================================*/
/*                                                                           */
/*===========================================================================*/
//Frequency Bandwidth
#define RSCMU_BAND_RESTRICT       0
#define RSCMU_BAND_WIDE           1
#define RSCMU_BANDWIDTH_30KHZ     1
#define RSCMU_BANDWIDTH_300KHZ    2

// Generator Modulation
#define RSCMU_SSB                 1
#define RSCMU_AM                  2
#define RSCMU_FM                  3
#define RSCMU_FMST                4
#define RSCMU_DSB                 5

#define RSCMU_STEREO_MONO         0
#define RSCMU_STEREO_LEFT         1
#define RSCMU_STEREO_RIGHT        2
    
//Input connectors
#define RSCMU_INPUT_RF1           0
#define RSCMU_INPUT_RF2           1
#define RSCMU_INPUT_RF4           2

//Output Connectors
#define RSCMU_OUTPUT_RF1          0
#define RSCMU_OUTPUT_RF2          1
#define RSCMU_OUTPUT_RF3          2

// Audio input signal
#define RSCMU_AFAN_AFIN           0
#define RSCMU_AFAN_AUX1           1

// Audio path coupling
#define RSCMU_AFAN_AC             0
#define RSCMU_AFAN_DC             1

// Audio weighting filter
//      RSCMU_OFF
#define RSCMU_CME                 1
#define RSCMU_CCI                 2
#define RSCMU_FILT_A              3

// Audio fixed band pass selection
#define RSCMU_BP01                1
#define RSCMU_BP02                2
#define RSCMU_BP03                3
#define RSCMU_BP04                4
#define RSCMU_BP05                5
#define RSCMU_BP06                6
#define RSCMU_BP07                7
#define RSCMU_BP08                8
#define RSCMU_BP09                9
#define RSCMU_BP10               10
#define RSCMU_BP11               11
#define RSCMU_BP12               12
#define RSCMU_BP13               13
#define RSCMU_BP14               14
#define RSCMU_BP15               15
#define RSCMU_BP16               16
#define RSCMU_BP17               17
#define RSCMU_BP18               18
#define RSCMU_BP19               19

// Speech Encoder Input
#define RSCMU_SPEN_HAND           0
#define RSCMU_SPEN_GEN            1
#define RSCMU_SPEN_AUX1           2

// Speech Decoder Output
#define RSCMU_SPD_HAND            0
#define RSCMU_SPD_ANAL            1
#define RSCMU_SPD_AUX2            2

// Limit Check
#define RSCMU_OK                  0
#define RSCMU_INV                 1
#define RSCMU_NMAU                2
#define RSCMU_NMAL                3

#define RSCMU_MATCH_MATC          0
#define RSCMU_MATCH_INV           1
#define RSCMU_MATCH_NMAT          2
#define RSCMU_MATCH_NTSC          3
#define RSCMU_MATCH_OUT           4
#define RSCMU_MATCH_NTR           5
#define RSCMU_MATCH_BNF           6
#define RSCMU_MATCH_NRAM          7
#define RSCMU_MATCH_OFF           8
#define RSCMU_MATCH_OFLOW         9
#define RSCMU_MATCH_UFLOW        10

#define RSCMU_MANUAL              0
#define RSCMU_AUTO                1
#define RSCMU_PCL                 2
#define RSCMU_ALWAYS              0

#define RSCMU_CURRENT             0
#define RSCMU_AVERAGE             1
#define RSCMU_MAXMIN              2
#define RSCMU_MAXIMUM             2
#define RSCMU_MINIMUM             3
#define RSCMU_AVERAGED            1 // Do not remove it is due to keep the compatibility

//Serial interface
#define RSCMU_APPL_TRAN           0
#define RSCMU_APPL_REM            1
#define RSCMU_APPL_PRIN           2

//Input/output attenuation
#define RSCMU_ATT_MIN           -50
#define RSCMU_ATT_MAX           +50

//Multiple Measurement
#define RSCMU_MULT_MEAS_MIN       1
#define RSCMU_MULT_MEAS_MAX       10000

//Absolute level on used Timeslot
//#define RSCMU_USEDSLOTMIN         -137.0
//#define RSCMU_USEDSLOTMAX         +13.0

//Frequency offset
#define RSCMU_FREQ_OFFSET_MIN     -135000
#define RSCMU_FREQ_OFFSET_MAX     +135000

//Power Level Range
#define RSCMU_LEV_RANGE_MIN            10
#define RSCMU_LEV_RANGE_MAX           100

//Test Points Number
#define RSCMU_TEST_PTS_MIN              1
#define RSCMU_TEST_PTS_MAX            560

#define RSCMU_REG_MAX               32767
#define RSCMU_SUB_REG_MAX              15
#define RSCMU_ADDR_PRIM_MAX            30
#define RSCMU_ADDR_SEC_MAX             30

#define RSCMU_DATABITS_MIN              7
#define RSCMU_DATABITS_MAX              8
#define RSCMU_STOPBITS_MIN              1
#define RSCMU_STOPBITS_MAX              2

#define RSCMU_SUM1                      1
#define RSCMU_SUM2                      2

//Keyboard Assignment
#define RSCMU_KBUS                0
#define RSCMU_KBGR                1

//positive / negative
#define RSCMU_POS                 1
#define RSCMU_NEG                 0

// Frequency hopping
#define RSCMU_REL                 0
#define RSCMU_ABS                 1

// Mode Values
#define RSCMU_VALUE_ALL           0
#define RSCMU_VALUE_ARIT          1
#define RSCMU_VALUE_MIN           2
#define RSCMU_VALUE_MAX           3
#define RSCMU_VALUE_IVAL          4

// Save-Recall
#define RSCMU_SAVE                0
#define RSCMU_RECALL              1
#define RSCMU_INT_STOR_DEVICE     0
#define RSCMU_EXT_STOR_DEVICE     1
#define RSCMU_DEF_STOR_DEVICE     2

// Filter
#define RSCMU_FILTER_GAUSSIAN     0
#define RSCMU_FILTER_NYQUIST      1
// Filter
#define RSCMU_FILTER_50KHZ       0
#define RSCMU_FILTER_100KHZ      1
#define RSCMU_FILTER_200KHZ      2
#define RSCMU_FILTER_300KHZ      3
#define RSCMU_FILTER_500KHZ      4
#define RSCMU_FILTER_1MHZ        5
#define RSCMU_FILTER_2MHZ        6
#define RSCMU_FILTER_3MHZ        7
#define RSCMU_FILTER_5MHZ        8

#define RSCMU_LP  1

#define RSCMU_IQ   0
#define RSCMU_PLW  1
#define RSCMU_PLUW 2

#define RSCMU_VOLT   0
#define RSCMU_DBM    1

#define RSCMU_PATH1   0
#define RSCMU_PATH2   1

#define RSCMU_PEAK   0
#define RSCMU_RMS    1


//IQ Recorder
#define RSCMU_IQREC_OK    0
#define RSCMU_IQREC_NTR   1
#define RSCMU_IQREC_OFLW  2
#define RSCMU_IQREC_INV   3

#define RSCMU_AF_CHAN_1  0
#define RSCMU_AF_CHAN_2  1

/*===========================================================================*/
/* RSCMU_Base_Globals is initialized for each Session in an 'init' function
/*  and defines the Driver's global datas
/*---------------------------------------------------------------------------*/
/* Instrument driver revision:
/*---------------------------------------------------------------------------*/

#define RSCMU_BASE_VERSION      "5.00.2"   // Instrument Driver Version String
#define RSCMU_BASE_CREATIONDATE "03/2009"  // Instrument Driver Creation Month/Year
#define RSCMU_BASE_CVIVERSION   "8.5"      // Used Labwindows/CVI Version

// Please do not edit this define. It is only a combination of the three defines above
#define RSCMU_BASE_REVISION "Rev " RSCMU_BASE_VERSION", "RSCMU_BASE_CREATIONDATE", CVI "RSCMU_BASE_CVIVERSION // Instrument Driver Revision

/*= Macros ==================================================================*/

#define CHECKERR(fCal) if (RSCMU_Status >= 0) RSCMU_Status = (fCal); \
                        else

#define CHECKRET(fCal) if (RSCMU_Status = (fCal), RSCMU_Status < 0)\
                            return RSCMU_Status; \
                        else
#define CHECKRETMSG(fCal) if (RSCMU_Status = (fCal), RSCMU_Status < 0)\
                            return RSCMU_Base_errorMessage (0,RSCMU_Status,errorMessage);\
                         else

#define CHKNULLP(value,error) if (value == VI_NULL) return RSCMU_Base_errorMessage(0,error, errorMessage)
#define RETMSG(fcal) return RSCMU_Base_errorMessage(0,fcal, errorMessage)

#define GET_VI_REAL64(value,string) str = strtok((char*) string, ",");\
                              value = RSCMU_atof(str)

#define GET_VI_INT32(value,string, delimiter) str = strtok((char*) string, delimiter);\
                              value = RSCMU_atol(str)

#define GET_VI_STRING(value,string) value = strtok((char*) string, ",");\

#define GET_WRT_BUF(vi) struct RSCMU_SESSION_Globals* pvar_base_globals;\
                        ViChar *wrtBuf;\
                        CHECKRET(viGetAttribute(vi, VI_ATTR_USER_DATA,(ViAddr)&pvar_base_globals));\
                        wrtBuf = pvar_base_globals->wrtBuf

#define GET_RD_BUF(vi)  struct RSCMU_SESSION_Globals* pvar_base_globals;\
                        ViChar* rdBuf;\
                        CHECKRET(viGetAttribute(vi, VI_ATTR_USER_DATA,(ViAddr)&pvar_base_globals));\
                        rdBuf = pvar_base_globals->rdBuf
#define GET_BUFS(vi)    struct RSCMU_SESSION_Globals* pvar_base_globals;\
                        ViChar *rdBuf;\
                        ViChar *wrtBuf;\
                        CHECKRET(viGetAttribute(vi, VI_ATTR_USER_DATA,(ViAddr)&pvar_base_globals));\
                        wrtBuf = pvar_base_globals->wrtBuf;\
                        rdBuf = pvar_base_globals->rdBuf

#define REMOVE_STRING_SIGNS(string)\
    string++;\
    string[strlen(string)-1] = '\0'

/*===========================================================================*/

#ifdef _OUTSIDEVEE_

// common structure for all sessions
struct RSCMU_SESSION_Globals
{
  ViChar        FGrp_Name [40];
  ViChar        DrvVersion [80];
  ViChar        CmuVersion [40];
  ViInt32       RSCMU_Type;
  ViInt32       RSCMU_FW_Version;
  ViInt32       RSCMU_primary_address;
  ViInt32       RSCMU_secondary_address;
  ViSession     RSCMU_SessionNb;
  ViChar        RSCMU_SCPIConnection[10];
  ViInt32       RSCMU_FileHandle;
  ViAddr        RSCMU_AddrTargetFile;
  ViInt16       RSCMU_StateTraceFile;
  ViBoolean     RSCMU_TRACE;
  ViBoolean     RSCMU_Stb;
  ViSession     RSCMU_RmSessionDefault;
  ViChar        rdBuf[RD_BUFFER_SIZE];
  ViChar        wrtBuf[WR_BUFFER_SIZE];
};

// Structure "RSCMU_Sec_Addr" is initialized for each sesssion in the 'RSCMU_Base_SystRemAddrSec' function
typedef struct RSCMU_Sec_Addr
{
  ViChar        FctGrp[30];
  ViSession     SessionNb;
} RSCMU_tSecAddr;

// Structure "RSCMU_Base_Globals" is initialized for each Session in an 'init' function
struct  RSCMU_Base_Globals
{
  struct RSCMU_SESSION_Globals RSCMU_tGlobal;
  struct RSCMU_Sec_Addr        RSCMU_tSecAddr[30];
};

// Structure is used to define Handover name for all signalling sessions.
typedef struct RSCMU_HandOver
{
   ViChar HandOverSessionName[30];
} RSCMU_tHandover;

// Structure to save the Multitone Test Tones definition (CONFigure:MULTitone:AFnChannel:TDEFinition)
struct RSCMU_TestTones
{
  ViInt32 frequency_Hz[20];
  ViInt32 level_mV[20];
  ViInt32 enable[20];
};

// Structure to save the Multitone limit lines
struct RSCMU_MultitoneLimits
{
  ViReal64 Upper_limits_dB[20];
  ViInt32  Upper_enable[20];
  ViReal64 Lower_limits_dB[20];
  ViInt32  Lower_enable[20];
};

// Structure "RSCMU_RF_NSig_Globals" is initialized for each Session in an 'init' function
struct  RSCMU_RF_NSig_Globals
{
  struct RSCMU_SESSION_Globals RSCMU_tGlobal;
};

// Structure "RSCMU_Audio_NSig_Globals" is initialized for each Session in an 'init' function
struct  RSCMU_Audio_NSig_Globals
{
  struct RSCMU_SESSION_Globals RSCMU_tGlobal;
  struct RSCMU_TestTones       RSCMU_tTestTones;
  struct RSCMU_MultitoneLimits RSCMU_tMultitoneLimits;
};

#endif // _OUTSIDEVEE_

/*****************************************************************************/
/* INIT Functions ===========================================================*/
/*****************************************************************************/

ViStatus _VI_FUNC RSCMU_Init_Base               (ViPSession, ViInt32, ViInt32, ViInt32, ViBoolean, ViBoolean, ViChar[]);
ViStatus _VI_FUNC RSCMU_Init_RF_NSig            (ViSession, ViPSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_Init_Audio_NSig         (ViSession, ViPSession, ViChar[]);

ViStatus _VI_FUNC RSCMU_Base_DefUserCorrLoss (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_Base_ConfUserCorrLossTablEnab (ViSession, ViBoolean, ViChar[]);

ViStatus _VI_FUNC RSCMU_Base_ConfUserCorrLossTablLine (ViSession,ViInt32,ViBoolean,ViReal64,ViBoolean,ViReal64,ViBoolean,ViReal64,ViBoolean,ViReal64,ViBoolean,ViReal64,ViChar[]);

ViStatus _VI_FUNC RSCMU_Base_ConfUserCorrLossTabl (ViSession,ViBoolean[],ViReal64[],ViBoolean[],ViReal64[],ViBoolean[],ViReal64[],ViBoolean[],ViReal64[],ViBoolean[],ViReal64[],ViChar[]);

ViStatus _VI_FUNC RSCMU_Base_SortUserCorrLossTabl (ViSession,ViChar[]);

/*****************************************************************************/
/* CLOSE Functions ===========================================================*/
/*****************************************************************************/

ViStatus _VI_FUNC RSCMU_Close_Base              (ViSession, ViChar[]);

ViStatus _VI_FUNC RSCMU_Close_RF_NSig           (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_Close_Audio_NSig        (ViSession, ViChar[]);

//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
//      Class: Common Commands
//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
ViStatus _VI_FUNC RSCMU_SystGtl (ViSession,ViChar[]);
ViStatus _VI_FUNC RSCMU_Systllo (ViSession, ViBoolean,ViChar[]);

//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
//      Class: Basic unit
//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
ViStatus _VI_FUNC RSCMU_Base_StatOper           (ViSession, ViInt32*, ViChar[]);
ViStatus _VI_FUNC RSCMU_Base_StatOperCond       (ViSession, ViInt32*, ViChar[]);
ViStatus _VI_FUNC RSCMU_Base_StatOperPtr        (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_Base_StatOperNtr        (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_Base_StatOperEnab       (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_Base_StatOperCmuSum       (ViSession, ViInt32, ViInt32*, ViChar[]);
ViStatus _VI_FUNC RSCMU_Base_StatOperCmuSumCond   (ViSession, ViInt32, ViInt32*, ViChar[]);
ViStatus _VI_FUNC RSCMU_Base_StatOperCmuSumPtr    (ViSession, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_Base_StatOperCmuSumNtr    (ViSession, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_Base_StatOperCmuSumEnab   (ViSession, ViInt32, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_Base_StatOperCmuSumCmu      (ViSession, ViInt32, ViInt32, ViInt32*, ViChar[]);
ViStatus _VI_FUNC RSCMU_Base_StatOperCmuSumCmuCond  (ViSession, ViInt32, ViInt32, ViInt32*, ViChar[]);
ViStatus _VI_FUNC RSCMU_Base_StatOperCmuSumCmuPtr   (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_Base_StatOperCmuSumCmuNtr   (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_Base_StatOperCmuSumCmuEnab  (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_Base_StatOperCmuAll     (ViSession, ViInt32[], ViChar[]);
ViStatus _VI_FUNC RSCMU_Base_StatOperCmuCle     (ViSession, ViChar[]);

ViStatus _VI_FUNC RSCMU_Base_StatQues           (ViSession, ViInt32*, ViChar[]);
ViStatus _VI_FUNC RSCMU_Base_StatQuesCond       (ViSession, ViInt32*, ViChar[]);
ViStatus _VI_FUNC RSCMU_Base_StatQuesPtr        (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_Base_StatQuesNtr        (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_Base_StatQuesEnab       (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_Base_StatPres           (ViSession, ViChar[]);

ViStatus _VI_FUNC RSCMU_Base_SystRemAddrPrim    (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_Base_SystRemAddrSec     (ViSession, ViInt32, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_Base_StatOperEvenSadd   (ViSession, ViInt32*, ViChar[], ViChar[]);

ViStatus _VI_FUNC RSCMU_Base_StatOperSymb       (ViSession, ViChar[], ViChar[]);
ViStatus _VI_FUNC RSCMU_Base_StatOperSymbEnab   (ViSession, ViChar[], ViChar[]);

ViStatus _VI_FUNC RSCMU_Base_ConfSyncFreqRef    (ViSession, ViReal64, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_Base_SenseSyncFreqRefLock (ViSession, ViInt32*, ViChar[]);

ViStatus _VI_FUNC RSCMU_Base_SystRemTpm (ViSession, ViBoolean, ViChar[]);
ViStatus _VI_FUNC RSCMU_Base_SystRemRdm (ViSession, ViBoolean, ViChar[]);

ViStatus _VI_FUNC RSCMU_Base_SystCommGpibAddr       (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_Base_SystCommSerAppl        (ViSession, ViInt32, ViInt32*, ViChar[]);
ViStatus _VI_FUNC RSCMU_Base_SystCommSerBaud        (ViSession, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_Base_SystCommSerBit         (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_Base_SystCommSerPar         (ViSession, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_Base_SystCommSerTranPace    (ViSession, ViInt32, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_Base_SystOptInf         (ViSession, ViChar[], ViChar[]);
ViStatus _VI_FUNC RSCMU_SystOptInfCurrent       (ViSession, ViChar[], ViChar[]);
ViStatus _VI_FUNC RSCMU_Base_SystOpt            (ViSession, ViChar[], ViChar[]);






















ViStatus _VI_FUNC RSCMU_Base_TCPIPPrimStaticIDefSet (ViSession,ViChar[]);

ViStatus _VI_FUNC RSCMU_Base_TCPIPPrimStaticIPAddress (ViSession,ViInt32, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_Base_TCPIPPrimStaticSubMask  (ViSession,ViInt32, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_Base_TCPIPPrimStaticDefGatew (ViSession,ViInt32, ViInt32, ViInt32, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_Base_TCPIPSecStaticIDefSet (ViSession,ViChar[]);

ViStatus _VI_FUNC RSCMU_Base_TCPIPSecMode (ViSession,ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_Base_TCPIPSecStaticIPAddress (ViSession,ViInt32, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_Base_TCPIPSecStaticSubMask  (ViSession,ViInt32, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_Base_TCPIPSecStaticDefGatew (ViSession,ViInt32, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_Base_TCPIPSecDynamicHName   (ViSession, ViChar[], ViChar[]);
ViStatus _VI_FUNC RSCMU_Base_TCPIPSecDynamicFCode   (ViSession, ViInt32 *, ViChar[]);
ViStatus _VI_FUNC RSCMU_Base_TCPIPSecDynamicDNS      (ViSession, ViInt32 *, ViInt32 *, ViInt32 *, ViInt32 *, ViChar[]);
ViStatus _VI_FUNC RSCMU_Base_TCPIPSecDynamicIPAddress (ViSession, ViInt32 *, ViInt32 *, ViInt32 *, ViInt32 *, ViChar[]);
ViStatus _VI_FUNC RSCMU_Base_TCPIPSecDynamicSubMask  (ViSession, ViInt32 *, ViInt32 *, ViInt32 *, ViInt32 *, ViChar[]);
ViStatus _VI_FUNC RSCMU_Base_TCPIPSecDynamicDefGatew (ViSession, ViInt32 *, ViInt32 *, ViInt32 *, ViInt32 *, ViChar[]);









ViStatus _VI_FUNC RSCMU_Base_SystPres           (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_Base_SystRes            (ViSession, ViChar[]);

ViStatus _VI_FUNC RSCMU_Base_RemTraceDisplay    (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_Base_RemTraceFile       (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_Base_SystGtrmComp       (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_Base_SystNvlDisable     (ViSession, ViChar[]);

ViStatus _VI_FUNC RSCMU_Base_SystMequ           (ViSession,ViChar[],ViChar[]);

ViStatus _VI_FUNC RSCMU_Base_SystTim            (ViSession, ViInt32, ViChar[], ViChar[], ViChar[]);

ViStatus _VI_FUNC RSCMU_Base_SystMiscKbe        (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_Base_SystMiscKeyb       (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_Base_SystMqu            (ViSession, ViChar[], ViChar[], ViChar[]);

ViStatus _VI_FUNC RSCMU_Base_SystMquItem        (ViSession, ViChar[], ViChar[], ViChar[]);

ViStatus _VI_FUNC RSCMU_Base_SensTempSyst       (ViSession, ViReal64*, ViChar[]);

ViStatus _VI_FUNC RSCMU_Base_SaveRecallAll      (ViSession, ViInt32, ViChar[], ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_SaveRecallCurrent       (ViSession, ViInt32, ViChar[], ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_Base_SetDefaultStorageDevice (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_Base_GetFileInfo        (ViSession, ViChar[], ViInt32, ViChar[], ViChar[]);
ViStatus _VI_FUNC RSCMU_Base_SetFileComment     (ViSession, ViChar[], ViChar[]);
ViStatus _VI_FUNC RSCMU_Base_ChangeDirectory    (ViSession, ViChar[], ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_Base_GetCurrDirectory   (ViSession, ViChar[], ViChar[]);
ViStatus _VI_FUNC RSCMU_Base_ScanDirectory      (ViSession, ViChar[], ViChar[]);
ViStatus _VI_FUNC RSCMU_Base_MakeDir            (ViSession, ViChar[], ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_Base_RemoveDir          (ViSession, ViChar[], ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_Base_DeleteFile         (ViSession, ViChar[], ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_Base_CopyFile           (ViSession, ViChar[], ViInt32, ViChar[], ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_Base_MoveFile           (ViSession, ViChar[], ViInt32, ViChar[], ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_Base_RenameFile         (ViSession, ViChar[], ViChar[], ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_RF_NSig_FetcRfgGlisStat (ViSession instrSession,
                                                 ViInt32 *generatorStatus,
                                                 ViChar errorMessage[]);

// ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
//      Class: RF Non Signalling
// ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

ViStatus _VI_FUNC RSCMU_RF_NSig_SensLevMax          (ViSession, ViReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_SensLevRef          (ViSession, ViReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_SensLevAtt          (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_SensLevMode         (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_RF_NSig_TrigSour            (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_TrigThr             (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_TrigSlop            (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_TrigThrRFPow        (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_TrigThrIFPow        (ViSession, ViReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_TrigSourExt         (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_RF_NSig_TrigMtg (ViSession instrSession,
                                         ViInt32 minimumTriggerGap,
                                         ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_RF_NSig_ConfIQIFRXTX        (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_ConfIQIFRXPath      (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_ConfIQIFTXPath      (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_RF_NSig_ConfWpowContRep (ViSession ,ViInt32 , ViInt32 ,ViInt32 ,ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_ConfWpowContRepStat (ViSession ,ViInt32 ,ViInt32 ,ViInt32 ,ViChar[]);

ViStatus _VI_FUNC RSCMU_RF_NSig_InitWpow (ViSession ,ViChar[] );
ViStatus _VI_FUNC RSCMU_RF_NSig_AborWpow (ViSession ,ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_ContWpow (ViSession ,ViChar[] );
ViStatus _VI_FUNC RSCMU_RF_NSig_StopWpow (ViSession ,ViChar[]);

ViStatus _VI_FUNC RSCMU_RF_NSig_FetcWpowStat (ViSession ,ViInt32*,ViInt32*,ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_ConfWpowErep (ViSession ,ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_RF_NSig_ReadWpow (ViSession ,ViReal64*, ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_FetcWpow (ViSession ,ViReal64*, ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_SampWpow (ViSession ,ViReal64*,ViChar[]);

ViStatus _VI_FUNC RSCMU_RF_NSig_SensNpowBwid        (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_ConfNpowCont        (ViSession, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_ConfNpowContRep     (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_ConfNpowContRepStat (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_ConfNpowContStat    (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_DefNpowConf         (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_RF_NSig_InitNpow            (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_AborNpow            (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_StopNpow            (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_ContNpow            (ViSession, ViChar[]);

ViStatus _VI_FUNC RSCMU_RF_NSig_FetcNpowStat        (ViSession, ViInt32*, ViInt32*, ViInt32*, ViChar[]);

ViStatus _VI_FUNC RSCMU_RF_NSig_ConfNpowErep        (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_RF_NSig_ReadNpow            (ViSession, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_FetcNpow            (ViSession, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_SampNpow            (ViSession, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViChar[]);

ViStatus _VI_FUNC RSCMU_RF_NSig_DefRfgConf          (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_SourRfgLev          (ViSession, ViReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_SourRfgFreq         (ViSession, ViReal64, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_RF_NSig_SourRfgMod          (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_SourRfgModSsbFreq   (ViSession, ViReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_SourRfgModAmInd     (ViSession, ViReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_SourRfgModFMFreq    (ViSession, ViReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_SourRfgModFMDev     (ViSession, ViReal64, ViChar[]);

ViStatus _VI_FUNC RSCMU_RF_NSig_SourRfgFhopStat      (ViSession, ViBoolean, ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_SourRfgFhopFreq      (ViSession, ViReal64, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_SourRfgFhopFreqMode  (ViSession, ViBoolean, ViChar[]);

ViStatus _VI_FUNC RSCMU_RF_NSig_SourRfgPulsStat     (ViSession, ViBoolean, ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_SourRfgBand         (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_RF_NSig_InitRfg             (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_AborRfg             (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_FetcRfgStat         (ViSession, ViPInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_RF_NSig_SourRfgLevAuxTx     (ViSession,ViReal64,ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_SourRfgFreqAuxTx    (ViSession,ViReal64,ViChar[]);





ViStatus _VI_FUNC RSCMU_RF_NSig_RfgAuxTxPathSel (ViSession,ViInt32,ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_SourRfgOverLevAuxTx (ViSession,ViInt32,ViBoolean ,ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_SourRfgLevAuxTxPath2 (ViSession,ViReal64,ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_SourRfgFreqAuxTxPath2 (ViSession,ViReal64,ViChar[]);





ViStatus _VI_FUNC RSCMU_RF_NSig_InitRfgAuxTx        (ViSession,ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_AborRfgAuxTx        (ViSession,ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_FetcRfgStatAuxTx    (ViSession,ViInt32*,ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_AuxTXOutp           (ViSession,ViInt32,ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_AuxTXCorrOut        (ViSession,ViInt32,ViReal64,ViChar[]);

ViStatus _VI_FUNC RSCMU_RF_NSig_RfanFreq            (ViSession, ViReal64, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_RfanBandRes         (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_ConfRfanPowRtim     (ViSession, ViReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_ConfRfanContRep     (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_DefRfanConf (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_RF_NSig_ConfRfanContRepStat (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_RF_NSig_InitRfan        (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_AborRfan        (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_StopRfan        (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_ContRfan        (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_FetcRfanStat    (ViSession, ViInt32*, ViInt32*, ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_ConfRfanErep    (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_RF_NSig_ReadRfanPow     (ViSession, ViReal64*, ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_FetcRfanPow     (ViSession, ViReal64*, ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_SampRfanPow     (ViSession, ViReal64*, ViChar[]);

ViStatus _VI_FUNC RSCMU_RF_NSig_Inp               (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_Outp              (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_SensCorrLossInp   (ViSession, ViInt32, ViReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_SourCorrLossOutp  (ViSession, ViInt32, ViReal64, ViChar[]);






ViStatus _VI_FUNC RSCMU_RF_NSig_AuxTXOvrLv (ViSession,ViInt32,ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_AuxTXCorrOvrLv (ViSession,ViInt32,ViReal64,ViChar[]);







ViStatus _VI_FUNC RSCMU_RF_NSig_SourDmCloc      (ViSession, ViInt32, ViReal64, ViChar[]);

ViStatus _VI_FUNC RSCMU_RF_NSig_SensPowLevRang    (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_RF_NSig_SensPowFreqCent   (ViSession, ViReal64, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_SensPowFreqBand   (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_SensPowTimeDel    (ViSession, ViReal64, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_SensPowTimeSpan   (ViSession, ViReal64, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_SensPowContTim    (ViSession, ViReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_ConfPowContRep    (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_DispPowContGrid   (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_DefPowConf (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_RF_NSig_ConfPowContRepStat  (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_RF_NSig_ConfArrPowRang    (ViSession, ViReal64, ViInt32, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_RF_NSig_ConfSubArrPow (ViSession, ViInt32, ViReal64, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_RF_NSig_InitPow         (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_AborPow         (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_StopPow         (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_ContPow         (ViSession, ViChar[]);

ViStatus _VI_FUNC RSCMU_RF_NSig_SourRfgModFMSTAudFreq (ViSession instrSession,
                                                       ViReal64 FMStereoAudioFrequency,
                                                       ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_RF_NSig_SourRfgModFMSTAudDev (ViSession instrSession,
                                                      ViReal64 FMStereoAudioDeviation,
                                                      ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_RF_NSig_SourRfgModFMSTPilDev (ViSession instrSession,
                                                      ViReal64 FMStereoPilotDeviation,
                                                      ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_RF_NSig_SourRfgModFMSTAudMapp (ViSession instrSession,
                                                       ViInt32 FMStereoAudioMapping,
                                                       ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_RF_NSig_SourRfgGlisStep (ViSession instrSession,
                                                 ViInt32 steps,
                                                 ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_RF_NSig_SourRfgGlisDwel (ViSession instrSession,
                                                 ViReal64 dwellTime,
                                                 ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_RF_NSig_SourRfgGlis (ViSession instrSession,
                                             ViInt32 number_ofPoints,
                                             ViInt32 offset,
                                             ViReal64 frequencyList[],
                                             ViReal64 powerList[],
                                             ViChar errorMessage[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_SensAflDef (ViSession instrSession,
                                            ViInt32 defaultSettings,
                                            ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_RF_NSig_FetcRfgGlisEol (ViSession instrSession,
                                                ViBoolean *defaultSettings,
                                                ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_RF_NSig_InitRfgGlis (ViSession instrSession,
                                             ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_RF_NSig_AborRfgGlis (ViSession instrSession,
                                             ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_RF_NSig_FetcPowStat     (ViSession, ViInt32*, ViInt32*, ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_ConfPowErep     (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_RF_NSig_ReadArrPower        (ViSession,ViInt32, ViReal64*, ViInt32*, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_FetcArrPower        (ViSession,ViInt32, ViReal64*, ViInt32*, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_SampArrPower        (ViSession,ViInt32, ViReal64*, ViInt32*, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_ReadArrPow        (ViSession,ViReal64*, ViInt32*, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_FetcArrPow        (ViSession,ViReal64*, ViInt32*, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_SampArrPow        (ViSession,ViReal64*, ViInt32*, ViReal64[], ViChar[]);

ViStatus _VI_FUNC RSCMU_RF_NSig_ReadSubArrPow (ViSession,ViInt32,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_FetcSubArrPow (ViSession,ViInt32,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_SampSubArrPow (ViSession,ViInt32,ViReal64[],ViChar[]);

ViStatus _VI_FUNC RSCMU_RF_NSig_SensSpecFreqStartStop (ViSession, ViReal64, ViInt32, ViReal64, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_SensSpecFreqCentSpan (ViSession, ViReal64, ViInt32, ViReal64, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_SensSpecFreqBand    (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_SensSpecLevRang   (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_RF_NSig_ConfSpecContRep     (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_DispSpecContGrid    (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_DefSpecConf (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_RF_NSig_ConfSpecDetector (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_RF_NSig_ConfSpecContRepStat (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_RF_NSig_ConfArrSpecRang   (ViSession, ViReal64, ViInt32, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_RF_NSig_ConfSubArrSpec (ViSession, ViInt32, ViReal64, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_RF_NSig_InitSpec          (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_AborSpec          (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_StopSpec          (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_ContSpec          (ViSession, ViChar[]);

ViStatus _VI_FUNC RSCMU_RF_NSig_FetcSpecStat      (ViSession, ViInt32*, ViInt32*, ViChar[]);

ViStatus _VI_FUNC RSCMU_RF_NSig_ConfSpecErep      (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_RF_NSig_ReadArrSpectrum       (ViSession, ViInt32, ViReal64*, ViInt32*, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_FetcArrSpectrum       (ViSession, ViInt32, ViReal64*, ViInt32*, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_SampArrSpectrum       (ViSession, ViInt32, ViReal64*, ViInt32*, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_ReadArrSpec       (ViSession, ViReal64*, ViInt32*, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_FetcArrSpec       (ViSession, ViReal64*, ViInt32*, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_SampArrSpec       (ViSession, ViReal64*, ViInt32*, ViReal64[], ViChar[]);

ViStatus _VI_FUNC RSCMU_RF_NSig_ReadSubArrSpec (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_FetcSubArrSpec (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_SampSubArrSpec (ViSession, ViInt32, ViReal64[], ViChar[]);

ViStatus _VI_FUNC RSCMU_RF_NSig_FetcSpecMarkerAbsolute (ViSession, ViReal64, ViReal64*, ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_FetcSpecMarkerRelative (ViSession, ViReal64, ViReal64, ViReal64*, ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_FetcSpecMarkerPeak (ViSession, ViReal64*, ViReal64*, ViChar[]);






ViStatus _VI_FUNC RSCMU_RF_NSig_ConfIQSlotDefSet (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_ConfIQSlotRep (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_ConfIQSlotNrSteps (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_RF_NSig_ConfIQSlotNrSubsweeps (ViSession instrSession,
                                                       ViInt32 subsweeps,
                                                       ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_RF_NSig_ConfIQSlotTrgOffset (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_ConfIQSlotStepLength (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_ConfIQSlotMesLength (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_ConfIQSlotFreqEstLimit (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_RF_NSig_ConfIQSlotContCtim (ViSession instrSession,
                                                    ViReal64 captureTimeout,
                                                    ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_RF_NSig_ConfIQSlotDisplFormat (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_ConfIQSlotSubarrayRange (ViSession, ViInt32, ViUInt32, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_RF_NSig_FetcIQSlotFreqOffs (ViSession,ViReal64 *,ViChar[]);

ViStatus _VI_FUNC RSCMU_RF_NSig_InitIQSlot (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_AborIQSlot (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_StopIQSlot (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_ContIQSlot (ViSession, ViChar[]);

ViStatus _VI_FUNC RSCMU_RF_NSig_FetcIQSlotStat (ViSession, ViInt32 *, ViInt32 *, ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_ConfIQSlotErep (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_RF_NSig_ReadArrIQSlotIAmpl (ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_FetchArrIQSlotIAmpl (ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_SampleArrIQSlotIAmpl (ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_ReadSubArrIQSlotIAmpl (ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_FetchSubArrIQSlotIAmpl (ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_SampleSubArrIQSlotIAmpl (ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_ReadArrIQSlotQAmpl (ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_FetchArrIQSlotQAmpl (ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_SampleArrIQSlotQAmpl (ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_ReadSubArrIQSlotQAmpl (ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_FetchSubArrIQSlotQAmpl (ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_SampleSubArrIQSlotQAmpl (ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_ReadArrIQSlotLevel (ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_FetchArrIQSlotLevel (ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_SampleArrIQSlotLevel (ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_ReadSubArrIQSlotLevel (ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_FetchSubArrIQSlotLevel (ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_SampleSubArrIQSlotLevel (ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_ReadArrIQSlotPhase (ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_FetchArrIQSlotPhase (ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_SampleArrIQSlotPhase (ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_ReadSubArrIQSlotPhase (ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_FetchSubArrIQSlotPhase (ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_SampleSubArrIQSlotPhase (ViSession, ViReal64[], ViChar[]);






ViStatus _VI_FUNC RSCMU_RF_NSig_ConfIQRecDefSet (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_ConfIQRecMesLength (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_ConfIQRecTDelay (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_ConfIQRecCTimeout (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_ConfIQRecFilter (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_ConfIQRecGFilter (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_ConfIQRecNFilter (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_ConfIQRecRMode (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_ConfIQRecLFormat (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_ConfIQRecSubarrayRange (ViSession, ViInt32, ViUInt32, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_RF_NSig_FetcIQRecFSBW (ViSession,ViInt32 *,ViInt32 *,ViInt32 *,ViChar[]);

ViStatus _VI_FUNC RSCMU_RF_NSig_InitIQRec (ViSession,ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_AborIQRec (ViSession,ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_StopIQRec (ViSession,ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_ContIQRec (ViSession,ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_FetcIQRecStat (ViSession,ViInt32 *,ViInt32 *,ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_ConfIQRecErep (ViSession,ViInt32,ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_ReadArrIQRecIAmpl (ViSession,ViInt32 *,ViInt32 *,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_FetchArrIQRecIAmpl (ViSession,ViInt32 *,ViInt32 *,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_SampleArrIQRecIAmpl (ViSession,ViInt32 *,ViInt32 *,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_ReadSubArrIQRecIAmpl (ViSession,ViInt32 *,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_FetchSubArrIQRecIAmpl (ViSession,ViInt32 *,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_SampleSubArrIQRecIAmpl (ViSession,ViInt32 *,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_ReadArrIQRecQAmpl (ViSession,ViInt32 *,ViInt32 *,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_FetchArrIQRecQAmpl (ViSession,ViInt32 *,ViInt32 *,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_SampleArrIQRecQAmpl (ViSession,ViInt32 *,ViInt32 *,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_ReadSubArrIQRecQAmpl (ViSession,ViInt32 *,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_FetchSubArrIQRecQAmpl (ViSession,ViInt32 *,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_SampleSubArrIQRecQAmpl (ViSession,ViInt32 *,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_ReadArrIQRecLevel (ViSession,ViInt32 *,ViInt32 *,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_FetchArrIQRecLevel (ViSession,ViInt32 *,ViInt32 *,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_SampleArrIQRecLevel (ViSession,ViInt32 *,ViInt32 *,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_ReadSubArrIQRecLevel (ViSession,ViInt32 *,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_FetchSubArrIQRecLevel (ViSession,ViInt32 *,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_SampleSubArrIQRecLevel (ViSession,ViInt32 *,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_ReadArrIQRecPhase (ViSession,ViInt32 *,ViInt32 *,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_FetchArrIQRecPhase (ViSession,ViInt32 *,ViInt32 *,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_SampleArrIQRecPhase (ViSession,ViInt32 *,ViInt32 *,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_ReadSubArrIQRecPhase (ViSession,ViInt32 *,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_FetchSubArrIQRecPhase (ViSession,ViInt32 *,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_SampleSubArrIQRecPhase (ViSession,ViInt32 *,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_ReadArrIQRecIQ (ViSession,ViInt32 *,ViInt32 *,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_FetchArrIQRecIQ (ViSession,ViInt32 *,ViInt32 *,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_SampleArrIQRecIQ (ViSession,ViInt32 *,ViInt32 *,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_ReadSubArrIQRecIQ (ViSession,ViInt32 *,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_FetchSubArrIQRecIQ (ViSession,ViInt32 *,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_SampleSubArrIQRecIQ (ViSession,ViInt32 *,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_ReadArrIQRecPL (ViSession,ViInt32 *,ViInt32 *,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_FetchArrIQRecPL (ViSession,ViInt32 *,ViInt32 *,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_SampleArrIQRecPL (ViSession,ViInt32 *,ViInt32 *,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_ReadSubArrIQRecPL (ViSession,ViInt32 *,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_FetchSubArrIQRecPL (ViSession,ViInt32 *,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_SampleSubArrIQRecPL (ViSession,ViInt32 *,ViReal64[],ViChar[]);







// ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
//      Class: Audio Non Signalling
// ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
ViStatus _VI_FUNC RSCMU_Audio_NSig_RoutSpen         (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_Audio_NSig_RoutSpd          (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_Audio_NSig_SensAflDef       (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_Audio_NSig_SensAflMode      (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_Audio_NSig_SensAflModeExt (ViSession instrumentHandle,
                                                   ViInt32 channel, ViInt32 mode,
                                                   ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_Audio_NSig_SensAflMax       (ViSession, ViReal64, ViChar[]);

ViStatus _VI_FUNC RSCMU_Audio_NSig_SensAflMaxExt (ViSession instrumentHandle,
                                                  ViInt32 channel,
                                                  ViReal64 maxLevel,
                                                  ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_Audio_NSig_SourAfgLev       (ViSession, ViReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU_Audio_NSig_SourAfg2Lev      (ViSession, ViReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU_Audio_NSig_SourAfgFreq      (ViSession, ViReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU_Audio_NSig_SourAfg2Freq     (ViSession, ViReal64, ViChar[]);

ViStatus _VI_FUNC RSCMU_Audio_NSig_InitAfg          (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_Audio_NSig_InitAfg2         (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_Audio_NSig_AborAfg          (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_Audio_NSig_AborAfg2         (ViSession, ViChar[]);

ViStatus _VI_FUNC RSCMU_Audio_NSig_FetcAfgStat      (ViSession, ViPInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_Audio_NSig_FetcAfg2Stat     (ViSession, ViPInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_Audio_NSig_ConfAfanContRep  (ViSession, ViInt32, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_Audio_NSig_ConfAfanContCoup (ViSession, ViInt32, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_Audio_NSig_ConfAfanMtr      (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_Audio_NSig_ConfAfanContDistFreq (ViSession, ViInt32, ViReal64, ViChar[]);

ViStatus _VI_FUNC RSCMU_Audio_NSig_ConfAfanFiltVBPFreq (ViSession, ViInt32, ViReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU_Audio_NSig_ConfAfanFiltVBPBW   (ViSession, ViInt32, ViReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU_Audio_NSig_ConfAfanFiltWeight  (ViSession, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_Audio_NSig_ConfAfanFiltBPass   (ViSession, ViInt32, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_Audio_NSig_ConfAnFiltACCoup (ViSession instrumentHandle,
                                                     ViInt32 input_used_for_audio_signal,
                                                     ViInt32 bandwidthACCoupling,
                                                     ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_Audio_NSig_ConfAnFiltDCCoup (ViSession instrumentHandle,
                                                     ViInt32 input_used_for_audio_signal,
                                                     ViInt32 bandwidthDCCoupling,
                                                     ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_Audio_NSig_InitAfan         (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_Audio_NSig_AborAfan         (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_Audio_NSig_StopAfan         (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_Audio_NSig_ContAfan         (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_Audio_NSig_FetcAfanStat     (ViSession, ViInt32, ViInt32*, ViInt32*, ViChar[]);
ViStatus _VI_FUNC RSCMU_Audio_NSig_ConfAfanErep     (ViSession, ViInt32, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_Audio_NSig_ReadAfan         (ViSession, ViInt32, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU_Audio_NSig_FetcAfan         (ViSession, ViInt32, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU_Audio_NSig_SampAfan         (ViSession, ViInt32, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViChar[]);

ViStatus _VI_FUNC RSCMU_Audio_NSig_SetAfglSignMode  (ViSession,ViInt32,ViChar[]);
ViStatus _VI_FUNC RSCMU_Audio_NSig_SetAfg2SignMode  (ViSession,ViInt32,ViChar[]);

ViStatus _VI_FUNC RSCMU_Audio_NSig_ReadAfanWF_VBP   (ViSession, ViInt32, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU_Audio_NSig_FetcAfanWF_VBP   (ViSession, ViInt32, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU_Audio_NSig_SampAfanWF_VBP   (ViSession, ViInt32, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViChar[]);

ViStatus _VI_FUNC RSCMU_Audio_NSig_ReadAfanWF_SINAD (ViSession instrumentHandle_AudioNSig,
                                                     ViInt32 input_used_for_audio_signal,
                                                     ViReal64 *ACVoltage1_Peak,
                                                     ViReal64 *ACVoltage1_RMS,
                                                     ViReal64 *DCVoltage,
                                                     ViReal64 *distorsion,
                                                     ViReal64 *ACVoltage2_Peak,
                                                     ViReal64 *ACVoltage2_RMS,
                                                     ViReal64 *frequency_counter,
                                                     ViReal64 *SINAD,
                                                     ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_Audio_NSig_FetcAfanWF_SINAD (ViSession instrumentHandle_AudioNSig,
                                                     ViInt32 input_used_for_audio_signal,
                                                     ViReal64 *ACVoltage1_Peak,
                                                     ViReal64 *ACVoltage1_RMS,
                                                     ViReal64 *DCVoltage,
                                                     ViReal64 *distorsion,
                                                     ViReal64 *ACVoltage2_Peak,
                                                     ViReal64 *ACVoltage2_RMS,
                                                     ViReal64 *frequency_counter,
                                                     ViReal64 *SINAD,
                                                     ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_Audio_NSig_SampAfanWF_SINAD (ViSession instrumentHandle_AudioNSig,
                                                     ViInt32 input_used_for_audio_signal,
                                                     ViReal64 *ACVoltage1_Peak,
                                                     ViReal64 *ACVoltage1_RMS,
                                                     ViReal64 *DCVoltage,
                                                     ViReal64 *distorsion,
                                                     ViReal64 *ACVoltage2_Peak,
                                                     ViReal64 *ACVoltage2_RMS,
                                                     ViReal64 *frequency_counter,
                                                     ViReal64 *SINAD,
                                                     ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_Audio_NSig_DispMultGrid     (ViSession, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_Audio_NSig_ConfMultRlev     (ViSession, ViInt32, ViReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU_Audio_NSig_ConfMultRmod     (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_Audio_NSig_ConfMultAfgl     (ViSession, ViInt32, ViReal64, ViChar[]);

ViStatus _VI_FUNC RSCMU_Audio_NSig_ConfMultContCoup (ViSession instrumentHandle_AudioNSig,
                                                     ViInt32 audio_channel,
                                                     ViInt32 AFPathCoupling,
                                                     ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_Audio_NSig_ConfMultContRep  (ViSession, ViInt32, ViInt32, ViInt32, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_Audio_NSig_ConfMultContRepExt (ViSession instrumentHandle_AudioNSig,
                                                       ViInt32 audio_channel,
                                                       ViInt32 repetition,
                                                       ViInt32 multipleMeasNbRepetition,
                                                       ViInt32 stopCondition,
                                                       ViInt32 stepMode,
                                                       ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_Audio_NSig_ConfMultTdefFreq (ViSession, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32,
                                                                ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_Audio_NSig_ConfMultTdefLev  (ViSession, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32,
                                                                ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_Audio_NSig_ConfMultTdefSwitch (ViSession, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32,
                                                                  ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_Audio_NSig_ConfMultTdef     (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_Audio_NSig_ConfMultTdefTone (ViSession, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_Audio_NSig_ConfMultTdefMode (ViSession, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_Audio_NSig_ConfMultTdefTlev (ViSession, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_Audio_NSig_DefMultTdef      (ViSession, ViInt32, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_Audio_NSig_ConfMultFiltBpasDcc (ViSession, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_Audio_NSig_ConfMultFiltBpasAcc (ViSession, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_Audio_NSig_ConfMultFiltWeight  (ViSession, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_Audio_NSig_DefMultFilt         (ViSession, ViInt32, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_Audio_NSig_ConfMultLimUppDef    (ViSession, ViReal64, ViReal64, ViReal64, ViReal64, ViReal64, ViReal64, ViReal64, ViReal64, ViReal64, ViReal64,
                                                                    ViReal64, ViReal64, ViReal64, ViReal64, ViReal64, ViReal64, ViReal64, ViReal64, ViReal64, ViReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU_Audio_NSig_ConfMultLimUppSwitch (ViSession, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32,
                                                                    ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_Audio_NSig_ConfMultLimUpp       (ViSession, ViInt32,  ViChar[]);
ViStatus _VI_FUNC RSCMU_Audio_NSig_ConfMultToneLimUpp   (ViSession, ViInt32, ViInt32, ViReal64, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_Audio_NSig_ConfMultLimLowDef    (ViSession, ViReal64, ViReal64, ViReal64, ViReal64, ViReal64, ViReal64, ViReal64, ViReal64, ViReal64, ViReal64,
                                                                    ViReal64, ViReal64, ViReal64, ViReal64, ViReal64, ViReal64, ViReal64, ViReal64, ViReal64, ViReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU_Audio_NSig_ConfMultLimLowSwitch (ViSession, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32,
                                                                    ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_Audio_NSig_ConfMultLimLow       (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_Audio_NSig_ConfMultToneLimLow   (ViSession, ViInt32, ViInt32, ViReal64, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_Audio_NSig_DefMultLim           (ViSession, ViInt32, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_Audio_NSig_ConfMultContRepStat (ViSession, ViInt32, ViInt32, ViInt32, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_Audio_NSig_ConfSubMultRang     (ViSession, ViInt32, ViInt32, ViInt32, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_Audio_NSig_InitMult (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_Audio_NSig_AborMult (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_Audio_NSig_StopMult (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_Audio_NSig_ContMult (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_Audio_NSig_FetcMultStat (ViSession, ViInt32, ViInt32 *, ViInt32 *, ViChar[]);

ViStatus _VI_FUNC RSCMU_Audio_NSig_ConfMultErep (ViSession, ViInt32, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_Audio_NSig_ReadMultTone (ViSession, ViInt32, ViInt32, ViReal64 *, ViChar[]);
ViStatus _VI_FUNC RSCMU_Audio_NSig_FetcMultTone (ViSession, ViInt32, ViInt32, ViReal64 *, ViChar[]);
ViStatus _VI_FUNC RSCMU_Audio_NSig_SampMultTone (ViSession, ViInt32, ViInt32, ViReal64 *, ViChar[]);
ViStatus _VI_FUNC RSCMU_Audio_NSig_CalcMultToneMatchLim (ViSession, ViInt32, ViInt32, ViInt32 *, ViChar[]);
ViStatus _VI_FUNC RSCMU_Audio_NSig_CalcMultMatchLim     (ViSession, ViInt32, ViInt32[], ViChar[]);

ViStatus _VI_FUNC RSCMU_Audio_NSig_ReadArrMult  (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_Audio_NSig_FetcArrMult  (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_Audio_NSig_SampArrMult  (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_Audio_NSig_CalcArrMultMatchLim (ViSession, ViInt32, ViInt32 *, ViInt32 *, ViChar[]);

ViStatus _VI_FUNC RSCMU_Audio_NSig_ReadSubMult  (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_Audio_NSig_FetcSubMult  (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_Audio_NSig_SampSubMult  (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_Audio_NSig_InitThd (ViSession instrumentHandle,
                                      ViInt32 channel, ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_Audio_NSig_AborThd (ViSession instrumentHandle,
                                      ViInt32 channel, ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_Audio_NSig_StopThd (ViSession instrumentHandle,
                                      ViInt32 channel, ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_Audio_NSig_ContThd (ViSession instrumentHandle,
                                      ViInt32 channel, ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_Audio_NSig_FetcThdStat (ViSession instrumentHandle,
                                          ViInt32 channel,
                                          ViInt32 *measurementStatus,
                                          ViInt32 *counter_for_current_stat_cycle,
                                          ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_Audio_NSig_ConfThdErep (ViSession instrumentHandle,
                                          ViInt32 channel,
                                          ViInt32 eventReporting,
                                          ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_Audio_NSig_ConfThdContRep (ViSession instrumentHandle,
                                             ViInt32 channel,
                                             ViInt32 repetitionMode,
                                             ViInt32 multipleMeasNbRepetition,
                                             ViInt32 stopCondition,
                                             ViInt32 stepMode,
                                             ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_Audio_NSig_ContThdHarmonics (ViSession instrumentHandle,
                                               ViInt32 channel,
                                               ViInt32 harmonics,
                                               ViBoolean enable,
                                               ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_Audio_NSig_ContThdTdefinition (ViSession instrumentHandle,
                                                 ViInt32 channel,
                                                 ViReal64 frequency,
                                                 ViReal64 level,
                                                 ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_Audio_NSig_ReadThdHarmonics (ViSession instrumentHandle,
                                               ViInt32 channel,
                                               ViInt32 harmonics,
                                               ViReal64 *harmonicsLevel,
                                               ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_Audio_NSig_FetcThdHarmonics (ViSession instrumentHandle,
                                               ViInt32 channel,
                                               ViInt32 harmonics,
                                               ViReal64 *harmonicsLevel,
                                               ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_Audio_NSig_ReadThd (ViSession instrumentHandle,
                                            ViInt32 audio_channel,
                                            ViReal64 *THDIn_dB,
                                            ViChar errorMessage[]);
ViStatus _VI_FUNC RSCMU_Audio_NSig_FetcThd (ViSession instrumentHandle,
                                            ViInt32 audio_channel,
                                            ViReal64 *THDIn_dB,
                                            ViChar errorMessage[]);
ViStatus _VI_FUNC RSCMU_Audio_NSig_ReadArrThd (ViSession instrumentHandle,
                                         ViInt32 channel,
                                         ViReal64 harmonicsLevels[],
                                         ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_Audio_NSig_FetcArrThd (ViSession instrumentHandle,
                                         ViInt32 channel,
                                         ViReal64 harmonicsLevels[],
                                         ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_Audio_NSig_MMIVersion   (ViSession,ViString,ViChar[]);

// ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
//      APPLICATION FUNCTIONS
// ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
ViStatus _VI_FUNC RSCMU_SendControlCommand (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_FetcStatus (ViSession, ViInt32, ViInt32, ViInt32*, ViInt32*, ViInt32*, ViChar[]);
ViStatus _VI_FUNC RSCMU_ConfReporting (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_ConfControl (ViSession, ViInt32,ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_ConfContDef (ViSession ,ViInt32 ,ViInt32 ,ViInt32 ,ViChar[]);
ViStatus _VI_FUNC RSCMU_ConfControlRep (ViSession, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_ConfContRepStat (ViSession, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_Npow (ViSession, ViInt32, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_Wpow (ViSession, ViInt32, ViReal64*, ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_MeasArrPow (ViSession,ViInt32,ViInt32, ViReal64*, ViInt32*, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_MeasSubArrPow (ViSession,ViInt32,ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_MeasArrSpec (ViSession,ViInt32,ViInt32, ViReal64*, ViInt32*, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_NSig_MeasSubArrSpec (ViSession,ViInt32,ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_RF_ConfSubarrays (ViSession, ViInt32, ViInt32, ViReal64, ViInt32, ViChar[]);

// ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
//        UTILITY ROUTINE DECLARATIONS (Exportable Functions)
// ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

#ifdef _OUTSIDEVEE_ // makes sure linker in CVI does not generate a warning
                    // that these functions do not have a function panel

ViBoolean _VI_FUNC RSCMU_invalidViBooleanRange (ViBoolean);
ViBoolean _VI_FUNC RSCMU_invalidViUInt16Range (ViUInt16, ViUInt16, ViUInt16);
ViBoolean _VI_FUNC RSCMU_invalidViInt16Range (ViInt16, ViInt16, ViInt16);
ViBoolean _VI_FUNC RSCMU_invalidViInt32Range (ViInt32, ViInt32, ViInt32);
ViBoolean _VI_FUNC RSCMU_invalidViReal64Range (ViReal64, ViReal64, ViReal64);
ViBoolean _VI_FUNC RSCMU_invalidViUInt32Range (ViUInt32, ViUInt32, ViUInt32);
ViBoolean _VI_FUNC RSCMU_invalidViReal32Range (ViReal32, ViReal32, ViReal32);

/* New middle level functions */
ViStatus _VI_FUNC RSCMU_checkVersion (ViSession vi,
                             ViInt32    version,
                             ViStatus   errorCode);
ViReal64 _VI_FUNC RSCMU_atof(ViString _VI_FAR str);
ViInt32 _VI_FUNC RSCMU_atol(ViString _VI_FAR str);
void _VI_FUNC RSCMU_atofArray(ViString _VI_FAR string, ViReal64 arr[]);
ViStatus _VI_FUNC RSCMU_atoCharArray(ViString _VI_FAR string, ViChar arr[]);
ViStatus _VI_FUNC RSCMU_atochar(ViString, ViChar* );
ViStatus _VI_FUNC RSCMU_setViInt32 (ViSession vi,
                           ViString cmd,
                           ViInt32 value,
                           ViInt32 min,
                           ViInt32 max,
                           ViStatus parameterErrorCode);
ViStatus _VI_FUNC RSCMU_getViInt32 (ViSession vi,
                           ViString cmd,
                           ViInt32 *value,
                           ViStatus parameterErrorCode);
ViStatus _VI_FUNC RSCMU_setViReal64 (ViSession vi,
                            ViString cmd,
                            ViReal64 value,
                            ViReal64 min,
                            ViReal64 max,
                            ViStatus parameterErrorCode);
ViStatus _VI_FUNC RSCMU_setViReal64Unit (ViSession vi,
                                       ViString cmd,
                                       ViReal64 value,
                                       ViReal64 min[],
                                       ViReal64 max[],
                                       ViInt32  unit,
                                       ViString unitArr[],
                                       ViStatus parameterErrorCode);
ViStatus _VI_FUNC RSCMU_getViReal64 (ViSession vi,
                            ViString cmd,
                            ViReal64 *value,
                            ViStatus parameterErrorCode);
ViStatus _VI_FUNC RSCMU_sendCmd (ViSession vi,
                        ViString cmd);
ViStatus _VI_FUNC RSCMU_setViString (ViSession vi,
                            ViString cmd,
                            ViString value,
                            ViStatus parameterErrorValue);
ViStatus _VI_FUNC RSCMU_getViString (ViSession vi,
                            ViString cmd,
                            ViString value,
                            ViInt32 buffer_size,
                            ViStatus parameterErrorCode);
ViStatus _VI_FUNC RSCMU_setEnum (ViSession vi,
                        ViString cmd,
                        ViInt32 value,
                        ViString _VI_FAR list[],
                        ViStatus parameterErrorCode);
ViStatus _VI_FUNC RSCMU_getEnum (ViSession vi,
                        ViString cmd,
                        ViInt32 *value,
                        ViString _VI_FAR list[],
                        ViStatus parameterErrorCode);
ViStatus _VI_FUNC RSCMU_checkIndexInList (ViSession vi,
                                 ViInt32 index,
                                 ViString list[],
                                 ViStatus statusIfError);
ViStatus _VI_FUNC RSCMU_checkIndexInRealList (ViSession vi,
                                 ViInt32 index,
                                 ViReal64 list[],
                                 ViStatus statusIfError);
ViStatus _VI_FUNC RSCMU_getIndexFromString (ViSession vi,
                                   ViString string,
                                   ViString *list,
                                   ViInt32 *index);
ViStatus _VI_FUNC RSCMU_WinBatchWrite (ViSession instrSession,
                         ViString _VI_FAR command);
ViStatus _VI_FUNC RSCMU_WinBatchRead (ViSession instrSession,
                         ViString _VI_FAR buffer);
ViStatus _VI_FUNC RSCMU_sysStatus (ViSession vi, ViUInt16* stb);
ViStatus _VI_FUNC RSCMU_setCheckStatus(ViSession vi, ViBoolean checkStatus);
ViStatus _VI_FUNC RSCMU_ReadDataUnknownLength(ViSession instrSession,
                                            ViChar **outBuffer,
                                            ViUInt32 *count);
ViStatus _VI_FUNC RSCMU_viWrite (ViSession, ViChar[], ViUInt32);
ViStatus _VI_FUNC RSCMU_viRead (ViSession, ViChar[], ViUInt32);
/* End of new middle level functions */

ViStatus _VI_FUNC RSCMU_Write (ViSession, ViChar[], ViBoolean, ViUInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_Read (ViSession, ViChar[], ViUInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_SeparateDataValues (ViChar[], ViChar[], ViChar[100][100]);
ViStatus _VI_FUNC RSCMU_ReturnCMUResponse (ViInt32, ViChar[669][20], ViReal64[]);
ViStatus _VI_FUNC RSCMU_GetViInt32Value (ViChar[100][100], ViInt32, ViInt32*);
ViStatus _VI_FUNC RSCMU_GetViReal64Value (ViChar[100][100], ViInt32, ViReal64*);
ViStatus _VI_FUNC RSCMU_GetLimitCheckValue (ViChar[100][100], ViInt32, ViInt32*);
ViStatus _VI_FUNC RSCMU_GetMeasStatVal (ViInt32*, ViChar[100][100], ViInt32);
ViStatus _VI_FUNC RSCMU_GetSensMeasStatVal (ViInt32*, ViChar[100][100], ViInt32);
ViStatus _VI_FUNC RSCMU_GetCountingNo (ViInt32*, ViChar[100][100], ViInt32);
ViStatus _VI_FUNC RSCMU_GetStatisticNo (ViInt32*, ViChar[100][100], ViInt32);
ViStatus _VI_FUNC RSCMU_GetMatchingValue (ViInt32*, ViChar[100][100], ViInt32);
ViInt32  _VI_FUNC RSCMU_GetGenStatVal (ViChar[]);
ViInt32  _VI_FUNC RSCMU_scanStringBurst (ViChar[], ViChar[669][20]);
ViStatus _VI_FUNC RSCMU_copyString (ViChar[], ViChar[], ViUInt32, ViUInt32);
ViStatus _VI_FUNC RSCMU_getTabSecAdd (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_WriteFile (ViSession, ViAddr, ViChar[],  ViChar[]);
ViStatus _VI_FUNC RSCMU_initCleanUp (ViSession, ViSession, ViStatus);

// ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
//      Function for LabVIEW 5.x and higher
// ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
ViStatus _VI_FUNC RSCMU_RF_NSig_GetResourceName (ViSession, ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_Audio_NSig_GetResourceName (ViSession, ViSession, ViChar[]);

#endif // _OUTSIDEVEE_

// ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
//      VXI PLUG & PLAY COMPATIBILITY FUNCTIONS
// ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

#ifndef _REMOVE_VXIPNP_FUNCTIONS_

ViStatus _VI_FUNC RSCMU_GetInstrumentHandle (ViSession, ViSession*);
ViStatus _VI_FUNC RSCMU_initRFNSig (ViSession, ViSession);
ViStatus _VI_FUNC RSCMU_initAudioNSig (ViSession, ViSession);

ViStatus _VI_FUNC RSCMU_init (ViRsrc, ViBoolean, ViBoolean, ViPSession);

ViStatus _VI_FUNC RSCMU_reset (ViSession);
ViStatus _VI_FUNC RSCMU_self_test (ViSession, ViPInt16, ViChar[]);
ViStatus _VI_FUNC RSCMU_error_query (ViSession, ViPInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_error_message (ViSession, ViStatus, ViChar[]);
ViStatus _VI_FUNC RSCMU_revision_query (ViSession, ViChar[], ViChar[]);
ViStatus _VI_FUNC RSCMU_close (ViSession);

#endif // _REMOVE_VXIPNP_FUNCTIONS_

// ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
//      UTILITY FUNCTIONS
// ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

ViStatus _VI_FUNC RSCMU_Reset          (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_SystResCurrent (ViSession, ViChar[]);

ViStatus _VI_FUNC RSCMU_Delay          (ViReal64);

//ViStatus _VI_FUNC RSCMU_SetCheckStatus_QueryDelay (ViSession ,ViReal64);

ViStatus _VI_FUNC RSCMU_SCPIVersionQuery (ViSession, ViChar[], ViChar[]);
ViStatus _VI_FUNC RSCMU_Base_RevisionQuery (ViSession, ViChar[], ViChar[], ViChar[]);
ViStatus _VI_FUNC RSCMU_CurrentVersion (ViSession, ViInt32*, ViChar[]);
ViStatus _VI_FUNC RSCMU_SetCmuVersion (ViSession, ViInt32, ViChar[], ViChar[]);

ViStatus _VI_FUNC RSCMU_ErrorQuery (ViSession, ViInt32*, ViChar[]);

ViStatus _VI_FUNC RSCMU_Trace_ON (ViSession, ViString, ViChar[]);
ViStatus _VI_FUNC RSCMU_Trace_OFF (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_WriteExtTrace   (ViSession, ViChar[], ViChar[]);

ViStatus _VI_FUNC RSCMU_Query (ViSession, ViChar[], ViChar[], ViBoolean, ViChar[]);

ViStatus _VI_FUNC RSCMU_Query_Array (ViSession, ViChar[], ViChar[], ViBoolean, ViChar[]);

ViStatus _VI_FUNC RSCMU_WriteToRSCMU (ViSession, ViChar[], ViChar[]);
ViStatus _VI_FUNC RSCMU_ReadFromRSCMU (ViSession, ViChar[], ViChar[]);

ViStatus _VI_FUNC RSCMU_SetTimeoutAttribute (ViSession, ViUInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_Base_errorMessage (ViSession, ViStatus, ViChar[]);

ViStatus _VI_FUNC RSCMU_SystGtrmComp (ViSession, ViBoolean, ViChar[]);

ViStatus _VI_FUNC RSCMU_FwVersionStringToIntegers(ViString, ViInt32*, ViInt32*);
ViStatus _VI_FUNC RSCMU_DrvVersionStringToIntegers(ViString, ViInt32*, ViInt32*);

ViStatus _VI_FUNC RSCMU_Dec2Bin(ViUInt32, ViChar*, ViChar*);
ViStatus _VI_FUNC RSCMU_MeasArray (ViSession, ViChar*, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_MeasArrayInt (ViSession,ViChar *,ViInt32[],ViChar[]);

// ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
//      MACROS
// ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

#ifdef _OUTSIDEVEE_

#define CHECK_VI_BOOLEAN_RANGE(instrSession,val,err,errorMessage) \
if (RSCMU_invalidViBooleanRange(val))                             \
return RSCMU_Base_errorMessage (instrSession,err,errorMessage);

#define CHECK_VI_INT32_RANGE(instrSession,val,min,max,err,errorMessage) \
if (RSCMU_invalidViInt32Range(val, min, max))                          \
return RSCMU_Base_errorMessage (instrSession,err,errorMessage);

#define CHECK_VI_REAL64_RANGE(instrSession,val,min, max, err,errorMessage) \
if (RSCMU_invalidViReal64Range(val, min, max))                             \
return RSCMU_Base_errorMessage (instrSession,err,errorMessage);

#define CHECK_VI_UINT32_RANGE(instrSession,val,min,max,err,errorMessage) \
if (RSCMU_invalidViUInt32Range(val, min, max))                            \
return RSCMU_Base_errorMessage (instrSession,err,errorMessage);

#endif // _OUTSIDEVEE_

#if defined(__cplusplus) || defined(__cplusplus__)
}
#endif

#endif // __RSCMU_HEADER

/*****************************************************************************/
/*=== END INCLUDE FILE ======================================================*/
/*****************************************************************************/
